/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "ns3/core-module.h"
#include "ns3/simulator-module.h"
#include "ns3/node-module.h"
#include "ns3/helper-module.h"
#include "ns3/wifi-module.h"
#include "ns3/mobility-module.h"
#include <fstream>

#define  ADHOC
#define  MANET

// Default Network Topology
//
//   Wifi 10.1.3.0
//                 AP   
//  *    *    *    *
//  |    |    |    |    10.1.1.0
// n5   n6   n7   n0 -------------- n1   n2   n3   n4
//                   point-to-point  |    |    |    |
//                                   ================
//                                     LAN 10.1.2.0

using namespace ns3;

NS_LOG_COMPONENT_DEFINE ("ThirdScriptExample");

int 
main (int argc, char *argv[])
{
  bool verbose = true;
//  uint32_t nCsma = 3;
  uint32_t nWifi = 30;
  uint32_t nManet = 10;
  uint32_t nP2p = 9;
  CommandLine cmd;
//  cmd.AddValue ("nCsma", "Number of \"extra\" CSMA nodes/devices", nCsma);
  cmd.AddValue ("nWifi", "Number of wifi STA devices", nWifi);
  cmd.AddValue ("verbose", "Tell echo applications to log if true", verbose);
  cmd.Parse (argc,argv);

  if (verbose)
    {
      LogComponentEnable("UdpEchoClientApplication", LOG_LEVEL_INFO);
      LogComponentEnable("UdpEchoServerApplication", LOG_LEVEL_INFO);
    }

  NodeContainer nC;
  nC.Create (nP2p);

  PointToPointHelper pointToPoint;
  pointToPoint.SetDeviceAttribute ("DataRate", StringValue ("100Mbps"));
  pointToPoint.SetChannelAttribute ("Delay", StringValue ("0.1ms"));

  NodeContainer p2p01 = NodeContainer (nC.Get(0), nC.Get (1));
  NodeContainer p2p02 = NodeContainer (nC.Get(0), nC.Get (2));
  NodeContainer p2p03 = NodeContainer (nC.Get(0), nC.Get (3));
  NodeContainer p2p04 = NodeContainer (nC.Get(0), nC.Get (4));
  NodeContainer p2p05 = NodeContainer (nC.Get(0), nC.Get (5));
  NodeContainer p2p06 = NodeContainer (nC.Get(0), nC.Get (6));
  NodeContainer p2p07 = NodeContainer (nC.Get(0), nC.Get (7));
  NodeContainer p2p08 = NodeContainer (nC.Get(0), nC.Get (8));
  NodeContainer p2p12 = NodeContainer (nC.Get(1), nC.Get (2));
  NodeContainer p2p13 = NodeContainer (nC.Get(1), nC.Get (3));
  NodeContainer p2p14 = NodeContainer (nC.Get(1), nC.Get (4));
  NodeContainer p2p15 = NodeContainer (nC.Get(1), nC.Get (5));
  NodeContainer p2p16 = NodeContainer (nC.Get(1), nC.Get (6));
  NodeContainer p2p17 = NodeContainer (nC.Get(1), nC.Get (7));
  NodeContainer p2p18 = NodeContainer (nC.Get(1), nC.Get (8));
  NodeContainer p2p23 = NodeContainer (nC.Get(2), nC.Get (3));
  NodeContainer p2p24 = NodeContainer (nC.Get(2), nC.Get (4));
  NodeContainer p2p25 = NodeContainer (nC.Get(2), nC.Get (5));
  NodeContainer p2p26 = NodeContainer (nC.Get(2), nC.Get (6));
  NodeContainer p2p27 = NodeContainer (nC.Get(2), nC.Get (7));
  NodeContainer p2p28 = NodeContainer (nC.Get(2), nC.Get (8));
  NodeContainer p2p34 = NodeContainer (nC.Get(3), nC.Get (4));
  NodeContainer p2p35 = NodeContainer (nC.Get(3), nC.Get (5));
  NodeContainer p2p36 = NodeContainer (nC.Get(3), nC.Get (6));
  NodeContainer p2p37 = NodeContainer (nC.Get(3), nC.Get (7));
  NodeContainer p2p38 = NodeContainer (nC.Get(3), nC.Get (8));
  NodeContainer p2p45 = NodeContainer (nC.Get(4), nC.Get (5));
  NodeContainer p2p46 = NodeContainer (nC.Get(4), nC.Get (6));
  NodeContainer p2p47 = NodeContainer (nC.Get(4), nC.Get (7));
  NodeContainer p2p48 = NodeContainer (nC.Get(4), nC.Get (8));
  NodeContainer p2p56 = NodeContainer (nC.Get(5), nC.Get (6));
  NodeContainer p2p57 = NodeContainer (nC.Get(5), nC.Get (7));
  NodeContainer p2p58 = NodeContainer (nC.Get(5), nC.Get (8));
  NodeContainer p2p67 = NodeContainer (nC.Get(6), nC.Get (7));
  NodeContainer p2p68 = NodeContainer (nC.Get(6), nC.Get (8));
  NodeContainer p2p78 = NodeContainer (nC.Get(7), nC.Get (8));


  NetDeviceContainer p2pDevices01 = pointToPoint.Install (p2p01);
  NetDeviceContainer p2pDevices02 = pointToPoint.Install (p2p02);
  NetDeviceContainer p2pDevices03 = pointToPoint.Install (p2p03);
  NetDeviceContainer p2pDevices04 = pointToPoint.Install (p2p04);
  NetDeviceContainer p2pDevices05 = pointToPoint.Install (p2p05);
  NetDeviceContainer p2pDevices06 = pointToPoint.Install (p2p06);
  NetDeviceContainer p2pDevices07 = pointToPoint.Install (p2p07);
  NetDeviceContainer p2pDevices08 = pointToPoint.Install (p2p08);
  NetDeviceContainer p2pDevices12 = pointToPoint.Install (p2p12);
  NetDeviceContainer p2pDevices13 = pointToPoint.Install (p2p13);
  NetDeviceContainer p2pDevices14 = pointToPoint.Install (p2p14);
  NetDeviceContainer p2pDevices15 = pointToPoint.Install (p2p15);
  NetDeviceContainer p2pDevices16 = pointToPoint.Install (p2p16);
  NetDeviceContainer p2pDevices17 = pointToPoint.Install (p2p17);
  NetDeviceContainer p2pDevices18 = pointToPoint.Install (p2p18);
  NetDeviceContainer p2pDevices23 = pointToPoint.Install (p2p23);
  NetDeviceContainer p2pDevices24 = pointToPoint.Install (p2p24);
  NetDeviceContainer p2pDevices25 = pointToPoint.Install (p2p25);
  NetDeviceContainer p2pDevices26 = pointToPoint.Install (p2p26);
  NetDeviceContainer p2pDevices27 = pointToPoint.Install (p2p27);
  NetDeviceContainer p2pDevices28 = pointToPoint.Install (p2p28);
  NetDeviceContainer p2pDevices34 = pointToPoint.Install (p2p34);
  NetDeviceContainer p2pDevices35 = pointToPoint.Install (p2p35);
  NetDeviceContainer p2pDevices36 = pointToPoint.Install (p2p36);
  NetDeviceContainer p2pDevices37 = pointToPoint.Install (p2p37);
  NetDeviceContainer p2pDevices38 = pointToPoint.Install (p2p38);
  NetDeviceContainer p2pDevices45 = pointToPoint.Install (p2p45);
  NetDeviceContainer p2pDevices46 = pointToPoint.Install (p2p46);
  NetDeviceContainer p2pDevices47 = pointToPoint.Install (p2p47);
  NetDeviceContainer p2pDevices48 = pointToPoint.Install (p2p48);
  NetDeviceContainer p2pDevices56 = pointToPoint.Install (p2p56);
  NetDeviceContainer p2pDevices57 = pointToPoint.Install (p2p57);
  NetDeviceContainer p2pDevices58 = pointToPoint.Install (p2p58);
  NetDeviceContainer p2pDevices67 = pointToPoint.Install (p2p67);
  NetDeviceContainer p2pDevices68 = pointToPoint.Install (p2p68);
  NetDeviceContainer p2pDevices78 = pointToPoint.Install (p2p78);

  NodeContainer wifiStaNodesWifi, wifiStaNodesManet01, wifiStaNodesManet02, wifiStaNodesManet03;
  wifiStaNodesWifi.Create (nWifi);
  wifiStaNodesManet01.Create (nManet);
  wifiStaNodesManet02.Create (nManet);
  wifiStaNodesManet03.Create (nManet);

  NodeContainer wifiApNode = NodeContainer (nC);

  YansWifiChannelHelper channel = YansWifiChannelHelper::Default ();
  YansWifiPhyHelper phy = YansWifiPhyHelper::Default ();
  phy.SetChannel (channel.Create ());

  WifiHelper wifi = WifiHelper::Default ();
//  wifi.SetRemoteStationManager ("ns3::AarfWifiManager");
  wifi.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
                                "DataMode", StringValue ("wifib-1mbs"));

  NqosWifiMacHelper mac = NqosWifiMacHelper::Default ();

  Ssid ssid = Ssid ("ns-3-ssid");
  mac.SetType ("ns3::NqapWifiMac", 
    "Ssid", SsidValue (ssid),
    "BeaconGeneration", BooleanValue (true),
    "BeaconInterval", TimeValue (Seconds (2.5)));

  NetDeviceContainer apDevices;
  apDevices = wifi.Install (phy, mac, wifiApNode);

  mac.SetType ("ns3::NqstaWifiMac", 
    "Ssid", SsidValue (ssid),
    "ActiveProbing", BooleanValue (false));

  NetDeviceContainer staDevicesWifi = wifi.Install (phy, mac, wifiStaNodesWifi);
  NetDeviceContainer staDevicesManet01 = wifi.Install (phy, mac, wifiStaNodesManet01);
  NetDeviceContainer staDevicesManet02 = wifi.Install (phy, mac, wifiStaNodesManet02);
  NetDeviceContainer staDevicesManet03 = wifi.Install (phy, mac, wifiStaNodesManet03);

  MobilityHelper mobility;
  Ptr<ListPositionAllocator> positionAllocAp01 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp02 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp03 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp04 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp05 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp06 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp07 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp08 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp09 = CreateObject<ListPositionAllocator> ();

  Ptr<BonnMotionPositionAllocator> positionAllocSta01 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta02 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta03 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta04 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta05 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta06 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta07 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta08 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta09 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta10 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta11 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta12 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta13 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta14 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta15 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta16 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta17 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta18 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta19 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta20 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta21 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta22 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta23 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta24 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta25 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta26 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta27 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta28 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta29 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta30 = CreateObject<BonnMotionPositionAllocator> ();

  mobility.SetMobilityModel ("ns3::RandomWalk2dMobilityModel",
  			 "Mode", StringValue ("Time"),
			 "Time", StringValue ("2s"),
			 "Speed", StringValue ("Constant:0.0"),
//			 "Speed", RandomVariableValue (UniformVariable (1.0, 3.0)),
			 "Bounds", RectangleValue (Rectangle (0, 1000.0, 0.0, 1000.0)));

  positionAllocAp01->Add (Vector (100, 100, 0.0));
  mobility.SetPositionAllocator (positionAllocAp01);
  mobility.Install (wifiApNode.Get (0));

  positionAllocAp02->Add (Vector (400, 100, 0.0));      
  mobility.SetPositionAllocator (positionAllocAp02);
  mobility.Install (wifiApNode.Get (1));

  positionAllocAp03->Add (Vector (900, 100, 0.0));      
  mobility.SetPositionAllocator (positionAllocAp03);
  mobility.Install (wifiApNode.Get (2));

  positionAllocAp04->Add (Vector (100, 400, 0.0));      
  mobility.SetPositionAllocator (positionAllocAp04);
  mobility.Install (wifiApNode.Get (3));

  positionAllocAp05->Add (Vector (400, 400, 0.0));
  mobility.SetPositionAllocator (positionAllocAp05);
  mobility.Install (wifiApNode.Get (4));

  positionAllocAp06->Add (Vector (900, 400, 0.0));      
  mobility.SetPositionAllocator (positionAllocAp06);
  mobility.Install (wifiApNode.Get (5));

  positionAllocAp07->Add (Vector (100, 900, 0.0));      
  mobility.SetPositionAllocator (positionAllocAp07);
  mobility.Install (wifiApNode.Get (6));

  positionAllocAp08->Add (Vector (400, 900, 0.0));
  mobility.SetPositionAllocator (positionAllocAp08);
  mobility.Install (wifiApNode.Get (7));

  positionAllocAp09->Add (Vector (900, 900, 0.0));
  mobility.SetPositionAllocator (positionAllocAp09);
  mobility.Install (wifiApNode.Get (8));


  positionAllocSta01->SetAttribute ("FileNumber", UintegerValue (1));
  positionAllocSta01->Add (Vector (130, 570, 0.0));
  positionAllocSta01->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta01);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta01)
                            );
  mobility.Install (wifiStaNodesWifi.Get (0));

  
  positionAllocSta02->SetAttribute ("FileNumber", UintegerValue (2));
  positionAllocSta02->Add (Vector (830, 170, 0.0));
  positionAllocSta02->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta02);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta02)
                            );
  mobility.Install (wifiStaNodesWifi.Get (1));

  
  positionAllocSta03->SetAttribute ("FileNumber", UintegerValue (3));
  positionAllocSta03->Add (Vector (730, 470, 0.0));
  positionAllocSta03->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta03);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta03)
                            );
  mobility.Install (wifiStaNodesWifi.Get (2));
  

  positionAllocSta04->SetAttribute ("FileNumber", UintegerValue (4));
  positionAllocSta04->Add (Vector (750, 710, 0.0));
  positionAllocSta04->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta04);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta04)
                            );
  mobility.Install (wifiStaNodesWifi.Get (3));
  

  positionAllocSta05->SetAttribute ("FileNumber", UintegerValue (5));
  positionAllocSta05->Add (Vector (930, 215, 0.0));
  positionAllocSta05->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta05);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta05)
                            );
  mobility.Install (wifiStaNodesWifi.Get (4));


  positionAllocSta06->SetAttribute ("FileNumber", UintegerValue (6));
  positionAllocSta06->Add (Vector (970, 910, 0.0));
  positionAllocSta06->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta06);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta06)
                            );
  mobility.Install (wifiStaNodesWifi.Get (5));
  

  positionAllocSta07->SetAttribute ("FileNumber", UintegerValue (7));
  positionAllocSta07->Add (Vector (130, 670, 0.0));
  positionAllocSta07->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta07);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta07)
                            );
  mobility.Install (wifiStaNodesWifi.Get (6));
  
  
  positionAllocSta08->SetAttribute ("FileNumber", UintegerValue (8));
  positionAllocSta08->Add (Vector (310, 420, 0.0));
  positionAllocSta08->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta08);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta08)
                            );
  mobility.Install (wifiStaNodesWifi.Get (7));
  
  
  positionAllocSta09->SetAttribute ("FileNumber", UintegerValue (9));
  positionAllocSta09->Add (Vector (530, 350, 0.0));
  positionAllocSta09->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta09);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta09)
                            );
  mobility.Install (wifiStaNodesWifi.Get (8));
  
  
  positionAllocSta10->SetAttribute ("FileNumber", UintegerValue (10));
  positionAllocSta10->Add (Vector (870, 210, 0.0));
  positionAllocSta10->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta10);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta10)
                            );
  mobility.Install (wifiStaNodesWifi.Get (9));
  
  
  positionAllocSta11->SetAttribute ("FileNumber", UintegerValue (11));
  positionAllocSta11->Add (Vector (120, 480, 0.0));
  positionAllocSta11->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta11);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta11)
                            );
  mobility.Install (wifiStaNodesWifi.Get (10));
  
  
  positionAllocSta12->SetAttribute ("FileNumber", UintegerValue (12));
  positionAllocSta12->Add (Vector (900, 950, 0.0));
  positionAllocSta12->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta12);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta12)
                            );
  mobility.Install (wifiStaNodesWifi.Get (11));
  
  
  positionAllocSta13->SetAttribute ("FileNumber", UintegerValue (13));
  positionAllocSta13->Add (Vector (180, 160, 0.0));
  positionAllocSta13->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta13);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta13)
                            );
  mobility.Install (wifiStaNodesWifi.Get (12));
  
  
  positionAllocSta14->SetAttribute ("FileNumber", UintegerValue (14));
  positionAllocSta14->Add (Vector (30, 370, 0.0));
  positionAllocSta14->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta14);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta14)
                            );
  mobility.Install (wifiStaNodesWifi.Get (13));
  
  
  positionAllocSta15->SetAttribute ("FileNumber", UintegerValue (15));
  positionAllocSta15->Add (Vector (945, 50, 0.0));
  positionAllocSta15->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta15);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta15)
                            );
  mobility.Install (wifiStaNodesWifi.Get (14));
  
  
  positionAllocSta16->SetAttribute ("FileNumber", UintegerValue (16));
  positionAllocSta16->Add (Vector (775, 570, 0.0));
  positionAllocSta16->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta16);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta16)
                            );
  mobility.Install (wifiStaNodesWifi.Get (15));
  
  
  positionAllocSta17->SetAttribute ("FileNumber", UintegerValue (17));
  positionAllocSta17->Add (Vector (630, 70, 0.0));
  positionAllocSta17->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta17);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta17)
                            );
  mobility.Install (wifiStaNodesWifi.Get (16));
  
  
  positionAllocSta18->SetAttribute ("FileNumber", UintegerValue (18));
  positionAllocSta18->Add (Vector (150, 680, 0.0));
  positionAllocSta18->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta18);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta18)
                            );
  mobility.Install (wifiStaNodesWifi.Get (17));
  
  
  positionAllocSta19->SetAttribute ("FileNumber", UintegerValue (19));
  positionAllocSta19->Add (Vector (430, 700, 0.0));
  positionAllocSta19->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta19);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta19)
                            );
  mobility.Install (wifiStaNodesWifi.Get (18));
  
  
  positionAllocSta20->SetAttribute ("FileNumber", UintegerValue (20));
  positionAllocSta20->Add (Vector (830, 470, 0.0));
  positionAllocSta20->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta20);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta20)
                            );
  mobility.Install (wifiStaNodesWifi.Get (19));
  
  
  positionAllocSta21->SetAttribute ("FileNumber", UintegerValue (21));
  positionAllocSta21->Add (Vector (185, 230, 0.0));
  positionAllocSta21->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta21);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta21)
                            );
  mobility.Install (wifiStaNodesWifi.Get (20));


  positionAllocSta22->SetAttribute ("FileNumber", UintegerValue (22));
  positionAllocSta22->Add (Vector (615, 830, 0.0));
  positionAllocSta22->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta22);  
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta22)
                            );
  mobility.Install (wifiStaNodesWifi.Get (21));


  positionAllocSta23->SetAttribute ("FileNumber", UintegerValue (23));
  positionAllocSta23->Add (Vector (195, 975, 0.0));
  positionAllocSta23->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta23);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta23)
                            );
  mobility.Install (wifiStaNodesWifi.Get (22));
  

  positionAllocSta24->SetAttribute ("FileNumber", UintegerValue (24));
  positionAllocSta24->Add (Vector (200, 180, 0.0));
  positionAllocSta24->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta24);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta24)
                            );
  mobility.Install (wifiStaNodesWifi.Get (23));


  positionAllocSta25->SetAttribute ("FileNumber", UintegerValue (25));
  positionAllocSta25->Add (Vector (615, 220, 0.0));
  positionAllocSta25->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta25);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta25)
                            );
  mobility.Install (wifiStaNodesWifi.Get (24));


  positionAllocSta26->SetAttribute ("FileNumber", UintegerValue (26));
  positionAllocSta26->Add (Vector (85, 130, 0.0));
  positionAllocSta26->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta26);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta26)
                            );
  mobility.Install (wifiStaNodesWifi.Get (25));


  positionAllocSta27->SetAttribute ("FileNumber", UintegerValue (27));
  positionAllocSta27->Add (Vector (215, 530, 0.0));
  positionAllocSta27->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta27);  
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta27)
                            );
  mobility.Install (wifiStaNodesWifi.Get (26));


  positionAllocSta28->SetAttribute ("FileNumber", UintegerValue (28));
  positionAllocSta28->Add (Vector (95, 775, 0.0));
  positionAllocSta28->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta28);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta28)
                            );
  mobility.Install (wifiStaNodesWifi.Get (27));
  

  positionAllocSta29->SetAttribute ("FileNumber", UintegerValue (29));
  positionAllocSta29->Add (Vector (800, 680, 0.0));
  positionAllocSta29->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta29);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta29)
                            );
  mobility.Install (wifiStaNodesWifi.Get (28));


  positionAllocSta30->SetAttribute ("FileNumber", UintegerValue (30));
  positionAllocSta30->Add (Vector (315, 920, 0.0));
  positionAllocSta30->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta30);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta30)
                            );
  mobility.Install (wifiStaNodesWifi.Get (29));
  

  Ptr<BonnMotionPositionAllocator> positionAllocSta31 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta32 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta33 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta34 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta35 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta36 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta37 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta38 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta39 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta40 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta41 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta42 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta43 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta44 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta45 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta46 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta47 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta48 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta49 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta50 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta51 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta52 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta53 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta54 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta55 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta56 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta57 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta58 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta59 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta60 = CreateObject<BonnMotionPositionAllocator> ();
  
  
  positionAllocSta31->SetAttribute ("FileNumber", UintegerValue (31));
  positionAllocSta31->Add (Vector (985, 630, 0.0));
  positionAllocSta31->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta31);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta31)
                            );
  mobility.Install (wifiStaNodesManet01.Get (0));


  positionAllocSta32->SetAttribute ("FileNumber", UintegerValue (32));
  positionAllocSta32->Add (Vector (215, 230, 0.0));
  positionAllocSta32->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta32);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta32)
                            );
  mobility.Install (wifiStaNodesManet01.Get (1));


  positionAllocSta33->SetAttribute ("FileNumber", UintegerValue (33));
  positionAllocSta33->Add (Vector (225, 190, 0.0));
  positionAllocSta33->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta33);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta33)
                            );
  mobility.Install (wifiStaNodesManet01.Get (2));
  

  positionAllocSta34->SetAttribute ("FileNumber", UintegerValue (34));
  positionAllocSta34->Add (Vector (190, 550, 0.0));
  positionAllocSta34->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta34);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta34)
                            );
  mobility.Install (wifiStaNodesManet01.Get (3));


  positionAllocSta35->SetAttribute ("FileNumber", UintegerValue (35));
  positionAllocSta35->Add (Vector (615, 980, 0.0));
  positionAllocSta35->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta35);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta35)
                            );
  mobility.Install (wifiStaNodesManet01.Get (4));


  positionAllocSta36->SetAttribute ("FileNumber", UintegerValue (36));
  positionAllocSta36->Add (Vector (615, 890, 0.0));
  positionAllocSta36->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta36);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta36)
                            );
  mobility.Install (wifiStaNodesManet01.Get (5));


  positionAllocSta37->SetAttribute ("FileNumber", UintegerValue (37));
  positionAllocSta37->Add (Vector (195, 825, 0.0));
  positionAllocSta37->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta37);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta37)
                            );
  mobility.Install (wifiStaNodesManet01.Get (6));
  

  positionAllocSta38->SetAttribute ("FileNumber", UintegerValue (38));
  positionAllocSta38->Add (Vector (525, 580, 0.0));
  positionAllocSta38->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta38);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta38)
                            );
  mobility.Install (wifiStaNodesManet01.Get (7));


  positionAllocSta39->SetAttribute ("FileNumber", UintegerValue (39));
  positionAllocSta39->Add (Vector (195, 880, 0.0));
  positionAllocSta39->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta39);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta39)
                            );
  mobility.Install (wifiStaNodesManet01.Get (8));


  positionAllocSta40->SetAttribute ("FileNumber", UintegerValue (40));
  positionAllocSta40->Add (Vector (215, 490, 0.0));
  positionAllocSta40->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta40);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta40)
                            );
  mobility.Install (wifiStaNodesManet01.Get (9));
  
  
  positionAllocSta41->SetAttribute ("FileNumber", UintegerValue (41));
  positionAllocSta41->Add (Vector (485, 430, 0.0));
  positionAllocSta41->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta41);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta41)
                            );
  mobility.Install (wifiStaNodesManet02.Get (0));


  positionAllocSta42->SetAttribute ("FileNumber", UintegerValue (42));
  positionAllocSta42->Add (Vector (615, 230, 0.0));
  positionAllocSta42->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta42);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta42)
                            );
  mobility.Install (wifiStaNodesManet02.Get (1));


  positionAllocSta43->SetAttribute ("FileNumber", UintegerValue (43));
  positionAllocSta43->Add (Vector (625, 790, 0.0));
  positionAllocSta43->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta43);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta43)
                            );
  mobility.Install (wifiStaNodesManet02.Get (2));
  

  positionAllocSta44->SetAttribute ("FileNumber", UintegerValue (44));
  positionAllocSta44->Add (Vector (190, 850, 0.0));
  positionAllocSta44->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta44);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta44)
                            );
  mobility.Install (wifiStaNodesManet02.Get (3));


  positionAllocSta45->SetAttribute ("FileNumber", UintegerValue (45));
  positionAllocSta45->Add (Vector (15, 480, 0.0));
  positionAllocSta45->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta45);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta45)
                            );
  mobility.Install (wifiStaNodesManet02.Get (4));


  positionAllocSta46->SetAttribute ("FileNumber", UintegerValue (46));
  positionAllocSta46->Add (Vector (150, 790, 0.0));
  positionAllocSta46->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta46);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta46)
                            );
  mobility.Install (wifiStaNodesManet02.Get (5));


  positionAllocSta47->SetAttribute ("FileNumber", UintegerValue (47));
  positionAllocSta47->Add (Vector (395, 725, 0.0));
  positionAllocSta47->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta47);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta47)
                            );
  mobility.Install (wifiStaNodesManet02.Get (6));
  

  positionAllocSta48->SetAttribute ("FileNumber", UintegerValue (48));
  positionAllocSta48->Add (Vector (325, 380, 0.0));
  positionAllocSta48->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta48);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta48)
                            );
  mobility.Install (wifiStaNodesManet02.Get (7));


  positionAllocSta49->SetAttribute ("FileNumber", UintegerValue (49));
  positionAllocSta49->Add (Vector (995, 880, 0.0));
  positionAllocSta49->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta49);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta49)
                            );
  mobility.Install (wifiStaNodesManet02.Get (8));


  positionAllocSta50->SetAttribute ("FileNumber", UintegerValue (50));
  positionAllocSta50->Add (Vector (215, 390, 0.0));
  positionAllocSta50->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta50);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta50)
                            );
  mobility.Install (wifiStaNodesManet02.Get (9));
  
  
  positionAllocSta26->SetAttribute ("FileNumber", UintegerValue (26));
  positionAllocSta26->Add (Vector (15, 190, 0.0));
  positionAllocSta26->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta26);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta26)
                            );
  mobility.Install (wifiStaNodesManet03.Get (0));


  positionAllocSta27->SetAttribute ("FileNumber", UintegerValue (27));
  positionAllocSta27->Add (Vector (195, 985, 0.0));
  positionAllocSta27->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta27);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta27)
                            );
  mobility.Install (wifiStaNodesManet03.Get (1));

  
  positionAllocSta28->SetAttribute ("FileNumber", UintegerValue (28));
  positionAllocSta28->Add (Vector (625, 620, 0.0));
  positionAllocSta28->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta28);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta28)
                            );
  mobility.Install (wifiStaNodesManet03.Get (2));


  positionAllocSta29->SetAttribute ("FileNumber", UintegerValue (29));
  positionAllocSta29->Add (Vector (995, 580, 0.0));
  positionAllocSta29->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta29);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta29)
                            );
  mobility.Install (wifiStaNodesManet03.Get (3));


  positionAllocSta30->SetAttribute ("FileNumber", UintegerValue (30));
  positionAllocSta30->Add (Vector (215, 590, 0.0));
  positionAllocSta30->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta30);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta30)
                            );
  mobility.Install (wifiStaNodesManet03.Get (4));


  positionAllocSta56->SetAttribute ("FileNumber", UintegerValue (56));
  positionAllocSta56->Add (Vector (50, 590, 0.0));
  positionAllocSta56->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta56);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta56)
                            );
  mobility.Install (wifiStaNodesManet03.Get (5));


  positionAllocSta57->SetAttribute ("FileNumber", UintegerValue (57));
  positionAllocSta57->Add (Vector (795, 25, 0.0));
  positionAllocSta57->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta57);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta57)
                            );
  mobility.Install (wifiStaNodesManet03.Get (6));
  

  positionAllocSta58->SetAttribute ("FileNumber", UintegerValue (58));
  positionAllocSta58->Add (Vector (925, 180, 0.0));
  positionAllocSta58->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta58);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta58)
                            );
  mobility.Install (wifiStaNodesManet03.Get (7));


  positionAllocSta59->SetAttribute ("FileNumber", UintegerValue (59));
  positionAllocSta59->Add (Vector (595, 480, 0.0));
  positionAllocSta59->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta59);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta59)
                            );
  mobility.Install (wifiStaNodesManet03.Get (8));


  positionAllocSta60->SetAttribute ("FileNumber", UintegerValue (60));
  positionAllocSta60->Add (Vector (115, 890, 0.0));
  positionAllocSta60->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta60);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta60)
                            );
  mobility.Install (wifiStaNodesManet03.Get (9));

#ifdef ADHOC
  NodeContainer adhoc (wifiStaNodesWifi, wifiStaNodesManet01, wifiStaNodesManet02, wifiStaNodesManet03);
  WifiHelper wifiAdhoc;
  NqosWifiMacHelper macAdhoc = NqosWifiMacHelper::Default ();
  macAdhoc.SetType ("ns3::AdhocWifiMac");
  wifiAdhoc.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
                                "DataMode", StringValue ("wifib-1mbs"));
  YansWifiPhyHelper wifiAdhocPhy = YansWifiPhyHelper::Default ();
  YansWifiChannelHelper wifiAdhocChannel = YansWifiChannelHelper::Default ();
  wifiAdhocPhy.SetChannel (wifiAdhocChannel.Create ());
  NetDeviceContainer adhocDevices = wifiAdhoc.Install (wifiAdhocPhy, macAdhoc, adhoc);
#endif

#ifdef MANET
  NodeContainer manetNodes01, manetNodes02, manetNodes03;
  manetNodes01.Create (nManet);
  NodeContainer manet01 (wifiStaNodesManet01, manetNodes01);
  WifiHelper wifiManet01;
  NqosWifiMacHelper macManet01 = NqosWifiMacHelper::Default ();
  macManet01.SetType ("ns3::AdhocWifiMac");
  wifiManet01.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
                                "DataMode", StringValue ("wifib-1mbs"));
  YansWifiPhyHelper wifiManetPhy01 = YansWifiPhyHelper::Default ();
  YansWifiChannelHelper wifiManetChannel01 = YansWifiChannelHelper::Default ();
  wifiManetPhy01.SetChannel (wifiManetChannel01.Create ());
  NetDeviceContainer manetDevices01 = wifiManet01.Install (wifiManetPhy01, macManet01, manet01);
  
  manetNodes02.Create (nManet);
  NodeContainer manet02 (wifiStaNodesManet02, manetNodes02);
  WifiHelper wifiManet02;
  NqosWifiMacHelper macManet02 = NqosWifiMacHelper::Default ();
  macManet02.SetType ("ns3::AdhocWifiMac");
  wifiManet02.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
                                "DataMode", StringValue ("wifib-1mbs"));
  YansWifiPhyHelper wifiManetPhy02 = YansWifiPhyHelper::Default ();
  YansWifiChannelHelper wifiManetChannel02 = YansWifiChannelHelper::Default ();
  wifiManetPhy02.SetChannel (wifiManetChannel02.Create ());
  NetDeviceContainer manetDevices02 = wifiManet02.Install (wifiManetPhy02, macManet02, manet02);
  
  manetNodes03.Create (nManet);
  NodeContainer manet03 (wifiStaNodesManet03, manetNodes03);
  WifiHelper wifiManet03;
  NqosWifiMacHelper macManet03 = NqosWifiMacHelper::Default ();
  macManet03.SetType ("ns3::AdhocWifiMac");
  wifiManet03.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
                                "DataMode", StringValue ("wifib-1mbs"));
  YansWifiPhyHelper wifiManetPhy03 = YansWifiPhyHelper::Default ();
  YansWifiChannelHelper wifiManetChannel03 = YansWifiChannelHelper::Default ();
  wifiManetPhy03.SetChannel (wifiManetChannel03.Create ());
  NetDeviceContainer manetDevices03 = wifiManet03.Install (wifiManetPhy03, macManet03, manet03);


  Ptr<ListPositionAllocator> positionAllocManet10 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet11 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet12 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet13 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet14 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet15 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet16 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet17 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet18 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet19 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet20 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet21 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet22 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet23 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet24 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet25 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet26 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet27 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet28 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet29 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet30 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet31 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet32 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet33 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet34 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet35 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet36 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet37 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet38 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocManet39 = CreateObject<ListPositionAllocator> ();
  
  
  mobility.SetMobilityModel ("ns3::RandomWalk2dMobilityModel",
  			 "Mode", StringValue ("Time"),
			 "Time", StringValue ("2s"),
			 "Speed", StringValue ("Constant:0.0"),
			 "Bounds", RectangleValue (Rectangle (0, 1000.0, 0.0, 1000.0)));

  positionAllocManet10->Add (Vector (200, 690, 0.0));
  positionAllocManet11->Add (Vector (270, 620, 0.0));
  positionAllocManet12->Add (Vector (280, 600, 0.0));
  positionAllocManet13->Add (Vector (240, 680, 0.0));
  positionAllocManet14->Add (Vector (290, 690, 0.0));
  positionAllocManet15->Add (Vector (230, 640, 0.0));
  positionAllocManet16->Add (Vector (210, 670, 0.0));
  positionAllocManet17->Add (Vector (260, 650, 0.0));
  positionAllocManet18->Add (Vector (250, 640, 0.0));
  positionAllocManet19->Add (Vector (240, 630, 0.0));
  
  
  mobility.SetPositionAllocator (positionAllocManet10);
  mobility.SetPositionAllocator (positionAllocManet11);
  mobility.SetPositionAllocator (positionAllocManet12);
  mobility.SetPositionAllocator (positionAllocManet13);
  mobility.SetPositionAllocator (positionAllocManet14);
  mobility.SetPositionAllocator (positionAllocManet15);
  mobility.SetPositionAllocator (positionAllocManet16);
  mobility.SetPositionAllocator (positionAllocManet17);
  mobility.SetPositionAllocator (positionAllocManet18);
  mobility.SetPositionAllocator (positionAllocManet19);
  
  
  mobility.Install (manetNodes01.Get (0));
  mobility.Install (manetNodes01.Get (1));
  mobility.Install (manetNodes01.Get (2));
  mobility.Install (manetNodes01.Get (3));
  mobility.Install (manetNodes01.Get (4));
  mobility.Install (manetNodes01.Get (5));
  mobility.Install (manetNodes01.Get (6));
  mobility.Install (manetNodes01.Get (7));
  mobility.Install (manetNodes01.Get (8));
  mobility.Install (manetNodes01.Get (9));
  
  
  positionAllocManet20->Add (Vector (600, 690, 0.0));
  positionAllocManet21->Add (Vector (670, 620, 0.0));
  positionAllocManet22->Add (Vector (680, 600, 0.0));
  positionAllocManet23->Add (Vector (640, 680, 0.0));
  positionAllocManet24->Add (Vector (690, 690, 0.0));
  positionAllocManet25->Add (Vector (630, 640, 0.0));
  positionAllocManet26->Add (Vector (610, 670, 0.0));
  positionAllocManet27->Add (Vector (660, 650, 0.0));
  positionAllocManet28->Add (Vector (650, 640, 0.0));
  positionAllocManet29->Add (Vector (640, 630, 0.0));
  
  
  mobility.SetPositionAllocator (positionAllocManet20);
  mobility.SetPositionAllocator (positionAllocManet21);
  mobility.SetPositionAllocator (positionAllocManet22);
  mobility.SetPositionAllocator (positionAllocManet23);
  mobility.SetPositionAllocator (positionAllocManet24);
  mobility.SetPositionAllocator (positionAllocManet25);
  mobility.SetPositionAllocator (positionAllocManet26);
  mobility.SetPositionAllocator (positionAllocManet27);
  mobility.SetPositionAllocator (positionAllocManet28);
  mobility.SetPositionAllocator (positionAllocManet29);
  
  
  mobility.Install (manetNodes02.Get (0));
  mobility.Install (manetNodes02.Get (1));
  mobility.Install (manetNodes02.Get (2));
  mobility.Install (manetNodes02.Get (3));
  mobility.Install (manetNodes02.Get (4));
  mobility.Install (manetNodes02.Get (5));
  mobility.Install (manetNodes02.Get (6));
  mobility.Install (manetNodes02.Get (7));
  mobility.Install (manetNodes02.Get (8));
  mobility.Install (manetNodes02.Get (9));
  
  
  positionAllocManet30->Add (Vector (600, 290, 0.0));
  positionAllocManet31->Add (Vector (670, 220, 0.0));
  positionAllocManet32->Add (Vector (680, 200, 0.0));
  positionAllocManet33->Add (Vector (640, 280, 0.0));
  positionAllocManet34->Add (Vector (690, 290, 0.0));
  positionAllocManet35->Add (Vector (630, 240, 0.0));
  positionAllocManet36->Add (Vector (610, 270, 0.0));
  positionAllocManet37->Add (Vector (660, 250, 0.0));
  positionAllocManet38->Add (Vector (650, 240, 0.0));
  positionAllocManet39->Add (Vector (640, 230, 0.0));
  
  
  mobility.SetPositionAllocator (positionAllocManet30);
  mobility.SetPositionAllocator (positionAllocManet31);
  mobility.SetPositionAllocator (positionAllocManet32);
  mobility.SetPositionAllocator (positionAllocManet33);
  mobility.SetPositionAllocator (positionAllocManet34);
  mobility.SetPositionAllocator (positionAllocManet35);
  mobility.SetPositionAllocator (positionAllocManet36);
  mobility.SetPositionAllocator (positionAllocManet37);
  mobility.SetPositionAllocator (positionAllocManet38);
  mobility.SetPositionAllocator (positionAllocManet39);
  
  
  mobility.Install (manetNodes03.Get (0));
  mobility.Install (manetNodes03.Get (1));
  mobility.Install (manetNodes03.Get (2));
  mobility.Install (manetNodes03.Get (3));
  mobility.Install (manetNodes03.Get (4));
  mobility.Install (manetNodes03.Get (5));
  mobility.Install (manetNodes03.Get (6));
  mobility.Install (manetNodes03.Get (7));
  mobility.Install (manetNodes03.Get (8));
  mobility.Install (manetNodes03.Get (9));

#endif  


  InternetStackHelper stack;
  static MeDeHaDtnRoutingHelper mdrouting;
  stack.Install (wifiApNode);

  static Ipv4GlobalRoutingHelper globalRouting;
  static Ipv4ListRoutingHelper listRouting1, listRouting2, listRouting3;
  
#ifdef MANET
  static OlsrHelper olsrRouting;

  listRouting1.Add (olsrRouting, 10);
  stack.SetRoutingHelper (listRouting1);
  stack.Install (manetNodes01);
  stack.Install (manetNodes02);
  stack.Install (manetNodes03);
#endif

  listRouting2.Add (olsrRouting, 10);
  listRouting2.Add (mdrouting, 4);
  stack.SetRoutingHelper (listRouting2);

//  stack.SetRoutingHelper (mdrouting);
//  stack.Install (adhoc);
  stack.Install (wifiStaNodesManet01);
  stack.Install (wifiStaNodesManet02);
  stack.Install (wifiStaNodesManet03);

//  listRouting3.Add (globalRouting, -10);
  listRouting3.Add (mdrouting, 4);
  stack.SetRoutingHelper (listRouting3);

  stack.Install (wifiStaNodesWifi);


  Ipv4AddressHelper address;


  Ipv4InterfaceContainer p2pInterfaces01, p2pInterfaces02, p2pInterfaces03, p2pInterfaces04, 
                         p2pInterfaces05, p2pInterfaces06, p2pInterfaces07, p2pInterfaces08;
  Ipv4InterfaceContainer p2pInterfaces12, p2pInterfaces13, p2pInterfaces14, p2pInterfaces15, 
                         p2pInterfaces16, p2pInterfaces17, p2pInterfaces18;
  Ipv4InterfaceContainer p2pInterfaces23, p2pInterfaces24, p2pInterfaces25, p2pInterfaces26, 
                         p2pInterfaces27, p2pInterfaces28;
  Ipv4InterfaceContainer p2pInterfaces34, p2pInterfaces35, p2pInterfaces36, p2pInterfaces37, 
                         p2pInterfaces38;
  Ipv4InterfaceContainer p2pInterfaces45, p2pInterfaces46, p2pInterfaces47, p2pInterfaces48;
  Ipv4InterfaceContainer p2pInterfaces56, p2pInterfaces57, p2pInterfaces58;
  Ipv4InterfaceContainer p2pInterfaces67, p2pInterfaces68;
  Ipv4InterfaceContainer p2pInterfaces78;

  address.SetBase ("10.1.3.0", "255.255.255.0");
  p2pInterfaces01 = address.Assign (p2pDevices01);
  address.SetBase ("11.1.3.0", "255.255.255.0");
  p2pInterfaces02 = address.Assign (p2pDevices02);
  address.SetBase ("12.1.3.0", "255.255.255.0");
  p2pInterfaces03 = address.Assign (p2pDevices03);
  address.SetBase ("13.1.3.0", "255.255.255.0");
  p2pInterfaces04 = address.Assign (p2pDevices04);
  address.SetBase ("14.1.3.0", "255.255.255.0");
  p2pInterfaces05 = address.Assign (p2pDevices05);
  address.SetBase ("15.1.3.0", "255.255.255.0");
  p2pInterfaces06 = address.Assign (p2pDevices06);
  address.SetBase ("16.1.3.0", "255.255.255.0");
  p2pInterfaces05 = address.Assign (p2pDevices07);
  address.SetBase ("17.1.3.0", "255.255.255.0");
  p2pInterfaces06 = address.Assign (p2pDevices08);

  address.SetBase ("18.1.3.0", "255.255.255.0");
  p2pInterfaces12 = address.Assign (p2pDevices12);
  address.SetBase ("19.1.3.0", "255.255.255.0");
  p2pInterfaces13 = address.Assign (p2pDevices13);
  address.SetBase ("20.1.3.0", "255.255.255.0");
  p2pInterfaces14 = address.Assign (p2pDevices14);
  address.SetBase ("21.1.3.0", "255.255.255.0");
  p2pInterfaces15 = address.Assign (p2pDevices15);
  address.SetBase ("22.1.3.0", "255.255.255.0");
  p2pInterfaces16 = address.Assign (p2pDevices16);
  address.SetBase ("23.1.3.0", "255.255.255.0");
  p2pInterfaces17 = address.Assign (p2pDevices17);
  address.SetBase ("24.1.3.0", "255.255.255.0");
  p2pInterfaces18 = address.Assign (p2pDevices18);

  address.SetBase ("25.1.3.0", "255.255.255.0");
  p2pInterfaces23 = address.Assign (p2pDevices23);
  address.SetBase ("26.1.3.0", "255.255.255.0");
  p2pInterfaces24 = address.Assign (p2pDevices24);
  address.SetBase ("27.1.3.0", "255.255.255.0");
  p2pInterfaces25 = address.Assign (p2pDevices25);
  address.SetBase ("28.1.3.0", "255.255.255.0");
  p2pInterfaces26 = address.Assign (p2pDevices26);
  address.SetBase ("29.1.3.0", "255.255.255.0");
  p2pInterfaces27 = address.Assign (p2pDevices27);
  address.SetBase ("30.1.3.0", "255.255.255.0");
  p2pInterfaces28 = address.Assign (p2pDevices28);

  address.SetBase ("31.1.3.0", "255.255.255.0");
  p2pInterfaces34 = address.Assign (p2pDevices34);
  address.SetBase ("32.1.3.0", "255.255.255.0");
  p2pInterfaces35 = address.Assign (p2pDevices35);
  address.SetBase ("33.1.3.0", "255.255.255.0");
  p2pInterfaces36 = address.Assign (p2pDevices36);
  address.SetBase ("34.1.3.0", "255.255.255.0");
  p2pInterfaces37 = address.Assign (p2pDevices37);
  address.SetBase ("35.1.3.0", "255.255.255.0");
  p2pInterfaces38 = address.Assign (p2pDevices38);

  address.SetBase ("36.1.3.0", "255.255.255.0");
  p2pInterfaces45 = address.Assign (p2pDevices45);
  address.SetBase ("37.1.3.0", "255.255.255.0");
  p2pInterfaces46 = address.Assign (p2pDevices46);
  address.SetBase ("38.1.3.0", "255.255.255.0");
  p2pInterfaces47 = address.Assign (p2pDevices47);
  address.SetBase ("39.1.3.0", "255.255.255.0");
  p2pInterfaces48 = address.Assign (p2pDevices48);

  address.SetBase ("40.1.3.0", "255.255.255.0");
  p2pInterfaces56 = address.Assign (p2pDevices56);
  address.SetBase ("41.1.3.0", "255.255.255.0");
  p2pInterfaces57 = address.Assign (p2pDevices57);
  address.SetBase ("42.1.3.0", "255.255.255.0");
  p2pInterfaces58 = address.Assign (p2pDevices58);

  address.SetBase ("43.1.3.0", "255.255.255.0");
  p2pInterfaces67 = address.Assign (p2pDevices67);
  address.SetBase ("44.1.3.0", "255.255.255.0");
  p2pInterfaces68 = address.Assign (p2pDevices68);

  address.SetBase ("45.1.3.0", "255.255.255.0");
  p2pInterfaces78 = address.Assign (p2pDevices78);

#ifdef ADHOC
  address.SetBase ("192.168.6.0", "255.255.255.0");
  Ipv4InterfaceContainer adhocInterfaces;
  adhocInterfaces = address.Assign (adhocDevices);
#endif

  address.SetBase ("10.1.1.0", "255.255.255.0");
  Ipv4InterfaceContainer apInterfaces = address.Assign (apDevices);
  Ipv4InterfaceContainer staInterfacesWifi = address.Assign (staDevicesWifi);
  Ipv4InterfaceContainer staInterfacesManet01 = address.Assign (staDevicesManet01);
  Ipv4InterfaceContainer staInterfacesManet02 = address.Assign (staDevicesManet02);
  Ipv4InterfaceContainer staInterfacesManet03 = address.Assign (staDevicesManet03);

#ifdef MANET
  address.SetBase ("192.168.7.0", "255.255.255.0");
  Ipv4InterfaceContainer manetInterfaces01 = address.Assign (manetDevices01);
  
  address.SetBase ("192.168.8.0", "255.255.255.0");
  Ipv4InterfaceContainer manetInterfaces02 = address.Assign (manetDevices02);
  
  address.SetBase ("192.168.9.0", "255.255.255.0");
  Ipv4InterfaceContainer manetInterfaces03 = address.Assign (manetDevices03);  
  
#endif

  Address dest01, dest02, dest03, dest04, dest05, dest06, dest07, dest08, dest09, dest10;
  Address dest11, dest12, dest13, dest14, dest15, dest16, dest17, dest18, dest19, dest20;
  std::string protocol;

  dest01 = InetSocketAddress (manetInterfaces01.GetAddress (0), 1025);
  dest02 = InetSocketAddress (manetInterfaces01.GetAddress (10), 1035);
  dest03 = InetSocketAddress (manetInterfaces01.GetAddress (1), 1045);
  dest04 = InetSocketAddress (manetInterfaces01.GetAddress (11), 1055);
  dest05 = InetSocketAddress (manetInterfaces01.GetAddress (2), 1065);
  dest06 = InetSocketAddress (manetInterfaces01.GetAddress (12), 1075);
  dest07 = InetSocketAddress (manetInterfaces01.GetAddress (3), 1085);
  dest08 = InetSocketAddress (manetInterfaces02.GetAddress (0), 1095);
  dest09 = InetSocketAddress (manetInterfaces02.GetAddress (10), 1105);
  dest10 = InetSocketAddress (manetInterfaces02.GetAddress (1), 1115);
  dest11 = InetSocketAddress (manetInterfaces02.GetAddress (11), 1125);
  dest12 = InetSocketAddress (manetInterfaces02.GetAddress (2), 1135);
  dest13 = InetSocketAddress (manetInterfaces02.GetAddress (12), 1145);
  dest14 = InetSocketAddress (manetInterfaces03.GetAddress (0), 1155);
  dest15 = InetSocketAddress (manetInterfaces03.GetAddress (10), 1165);
  dest16 = InetSocketAddress (manetInterfaces03.GetAddress (1), 1175);
  dest17 = InetSocketAddress (manetInterfaces03.GetAddress (11), 1185);
  dest18 = InetSocketAddress (manetInterfaces03.GetAddress (2), 1195);
  dest19 = InetSocketAddress (manetInterfaces03.GetAddress (12), 1205);
  dest20 = InetSocketAddress (manetInterfaces03.GetAddress (3), 1215);

  protocol = "ns3::UdpSocketFactory";

  OnOffHelper onoff01 = OnOffHelper (protocol, dest01);
  onoff01.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff01.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff01.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps00 = onoff01.Install (wifiStaNodesWifi.Get (0));
  apps00.Start (Seconds (20.0));
  apps00.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink01 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1025));

  ApplicationContainer apps01 = sink01.Install (manet01.Get (0));
  apps01.Start (Seconds (2.0));
  apps01.Stop (Seconds (3599.0));

  OnOffHelper onoff02 = OnOffHelper (protocol, dest02);
  onoff02.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff02.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff02.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps10 = onoff02.Install (wifiStaNodesManet02.Get (0));
  apps10.Start (Seconds (20.0));
  apps10.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink02 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1035));

  ApplicationContainer apps11 = sink02.Install (manet01.Get (10));
  apps11.Start (Seconds (2.0));
  apps11.Stop (Seconds (3599.0));

  OnOffHelper onoff03 = OnOffHelper (protocol, dest03);
  onoff03.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff03.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff03.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps20 = onoff03.Install (wifiStaNodesWifi.Get (1));
  apps20.Start (Seconds (20.0));
  apps20.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink03 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1045));

  ApplicationContainer apps21 = sink03.Install (manet01.Get (1));
  apps21.Start (Seconds (2.0));
  apps21.Stop (Seconds (3599.0));

  OnOffHelper onoff04 = OnOffHelper (protocol, dest04);
  onoff04.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff04.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff04.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps30 = onoff04.Install (wifiStaNodesManet02.Get (1));
  apps30.Start (Seconds (20.0));
  apps30.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink04 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1055));

  ApplicationContainer apps31 = sink04.Install (manet01.Get (11));
  apps31.Start (Seconds (2.0));
  apps31.Stop (Seconds (3599.0));

  OnOffHelper onoff05 = OnOffHelper (protocol, dest05);
  onoff05.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff05.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff05.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps40 = onoff05.Install (wifiStaNodesWifi.Get (2));
  apps40.Start (Seconds (20.0));
  apps40.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink05 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1065));

  ApplicationContainer apps41 = sink05.Install (manet01.Get (2));
  apps41.Start (Seconds (2.0));
  apps41.Stop (Seconds (3599.0));

  OnOffHelper onoff06 = OnOffHelper (protocol, dest06);
  onoff06.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff06.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff06.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps50 = onoff06.Install (wifiStaNodesManet03.Get (2));
  apps50.Start (Seconds (20.0));
  apps50.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink06 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1075));

  ApplicationContainer apps51 = sink06.Install (manet01.Get (12));
  apps51.Start (Seconds (2.0));
  apps51.Stop (Seconds (3599.0));

  OnOffHelper onoff07 = OnOffHelper (protocol, dest07);
  onoff07.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff07.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff07.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps60 = onoff07.Install (wifiStaNodesWifi.Get (3));
  apps60.Start (Seconds (20.0));
  apps60.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink07 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1085));

  ApplicationContainer apps61 = sink07.Install (manet01.Get (3));
  apps61.Start (Seconds (2.0));
  apps61.Stop (Seconds (3599.0));

  OnOffHelper onoff08 = OnOffHelper (protocol, dest08);
  onoff08.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff08.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff08.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps70 = onoff08.Install (wifiStaNodesManet03.Get (3));
  apps70.Start (Seconds (20.0));
  apps70.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink08 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1095));

  ApplicationContainer apps71 = sink08.Install (manet02.Get (0));
  apps71.Start (Seconds (2.0));
  apps71.Stop (Seconds (3599.0));

  OnOffHelper onoff09 = OnOffHelper (protocol, dest09);
  onoff09.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff09.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff09.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps80 = onoff09.Install (wifiStaNodesWifi.Get (4));
  apps80.Start (Seconds (20.0));
  apps80.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink09 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1105));

  ApplicationContainer apps81 = sink09.Install (manet02.Get (10));
  apps81.Start (Seconds (2.0));
  apps81.Stop (Seconds (3599.0));

  OnOffHelper onoff10 = OnOffHelper (protocol, dest10);
  onoff10.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff10.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff10.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps90 = onoff10.Install (wifiStaNodesManet03.Get (4));
  apps90.Start (Seconds (20.0));
  apps90.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink10 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1115));

  ApplicationContainer apps91 = sink10.Install (manet02.Get (1));
  apps91.Start (Seconds (2.0));
  apps91.Stop (Seconds (3599.0));

  OnOffHelper onoff11 = OnOffHelper (protocol, dest11);
  onoff11.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff11.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff11.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps100 = onoff11.Install (wifiStaNodesWifi.Get (5));
  apps100.Start (Seconds (20.0));
  apps100.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink11 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1125));

  ApplicationContainer apps101 = sink11.Install (manet02.Get (11));
  apps101.Start (Seconds (2.0));
  apps101.Stop (Seconds (3599.0));

  OnOffHelper onoff12 = OnOffHelper (protocol, dest12);
  onoff12.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff12.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff12.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps110 = onoff12.Install (wifiStaNodesManet01.Get (5));
  apps110.Start (Seconds (20.0));
  apps110.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink12 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1135));

  ApplicationContainer apps111 = sink12.Install (manet02.Get (2));
  apps111.Start (Seconds (2.0));
  apps111.Stop (Seconds (3599.0));

  OnOffHelper onoff13 = OnOffHelper (protocol, dest13);
  onoff13.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff13.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff13.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps120 = onoff13.Install (wifiStaNodesWifi.Get (6));
  apps120.Start (Seconds (20.0));
  apps120.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink13 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1145));

  ApplicationContainer apps121 = sink13.Install (manet02.Get (12));
  apps121.Start (Seconds (2.0));
  apps121.Stop (Seconds (3599.0));

  OnOffHelper onoff14 = OnOffHelper (protocol, dest14);
  onoff14.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff14.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff14.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps130 = onoff14.Install (wifiStaNodesManet01.Get (6));
  apps130.Start (Seconds (20.0));
  apps130.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink14 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1155));

  ApplicationContainer apps131 = sink14.Install (manet03.Get (0));
  apps131.Start (Seconds (2.0));
  apps131.Stop (Seconds (3599.0));

  OnOffHelper onoff15 = OnOffHelper (protocol, dest15);
  onoff15.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff15.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff15.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps140 = onoff15.Install (wifiStaNodesWifi.Get (7));
  apps140.Start (Seconds (20.0));
  apps140.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink15 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1165));

  ApplicationContainer apps141 = sink15.Install (manet03.Get (10));
  apps141.Start (Seconds (2.0));
  apps141.Stop (Seconds (3599.0));

  OnOffHelper onoff16 = OnOffHelper (protocol, dest16);
  onoff16.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff16.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff16.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps150 = onoff16.Install (wifiStaNodesManet01.Get (7));
  apps150.Start (Seconds (20.0));
  apps150.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink16 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1175));

  ApplicationContainer apps151 = sink16.Install (manet03.Get (1));
  apps151.Start (Seconds (2.0));
  apps151.Stop (Seconds (3599.0));

  OnOffHelper onoff17 = OnOffHelper (protocol, dest17);
  onoff17.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff17.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff17.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps160 = onoff17.Install (wifiStaNodesWifi.Get (8));
  apps160.Start (Seconds (20.0));
  apps160.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink17 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1185));

  ApplicationContainer apps161 = sink17.Install (manet03.Get (11));
  apps161.Start (Seconds (2.0));
  apps161.Stop (Seconds (3599.0));

  OnOffHelper onoff18 = OnOffHelper (protocol, dest18);
  onoff18.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff18.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff18.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps170 = onoff18.Install (wifiStaNodesManet02.Get (8));
  apps170.Start (Seconds (20.0));
  apps170.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink18 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1195));

  ApplicationContainer apps171 = sink18.Install (manet03.Get (2));
  apps171.Start (Seconds (2.0));
  apps171.Stop (Seconds (3599.0));

  OnOffHelper onoff19 = OnOffHelper (protocol, dest19);
  onoff19.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff19.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff19.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps180 = onoff19.Install (wifiStaNodesWifi.Get (9));
  apps180.Start (Seconds (20.0));
  apps180.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink19 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1205));

  ApplicationContainer apps181 = sink19.Install (manet03.Get (12));
  apps181.Start (Seconds (2.0));
  apps181.Stop (Seconds (3599.0));

  OnOffHelper onoff20 = OnOffHelper (protocol, dest20);
  onoff20.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff20.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff20.SetAttribute ("DataRate", DataRateValue (DataRate ("1kbps")));
  ApplicationContainer apps190 = onoff20.Install (wifiStaNodesManet03.Get (9));
  apps190.Start (Seconds (20.0));
  apps190.Stop (Seconds (1119.0));

  // Create a packet sink to receive these packets
  PacketSinkHelper sink20 ("ns3::UdpSocketFactory",
                         InetSocketAddress (Ipv4Address::GetAny (), 1215));

  ApplicationContainer apps191 = sink20.Install (manet03.Get (3));
  apps191.Start (Seconds (2.0));
  apps191.Stop (Seconds (3599.0));

  Ipv4GlobalRoutingHelper::PopulateRoutingTables ();
//  phy.EnablePcapAll ("test-medeha");

//  std::cout << "Src 01 Address = " << staInterfaces01.GetAddress (0) << "\n";
//  std::cout << "Dst 01 Address = " << staInterfaces02.GetAddress (0) << "\n";
//  std::cout << "Sta 01 Address = " << staInterfaces02.GetAddress (0) << "\n";
//  std::cout << "Sta 02 Address = " << staInterfaces02.GetAddress (1) << "\n";
  std::cout << "P2P 01 Address = " << p2pInterfaces01.GetAddress (0) << "\n";
  std::cout << "P2P 02 Address = " << p2pInterfaces01.GetAddress (1) << "\n";
  std::cout << "AP 01 Address = " << apInterfaces.GetAddress (0) << "\n";
  std::cout << "AP 02 Address = " << apInterfaces.GetAddress (1) << "\n";

  std::ofstream os;
  os.open ("test-medeha.mob");
  MobilityHelper::EnableAsciiAll (os);

//   std::ofstream phyTr;
//   phyTr.open ("test-medeha-phy.tr");
//   YansWifiPhyHelper::EnableAsciiAll (phyTr);

  Simulator::Stop (Seconds (3600.0));

  Simulator::Run ();
  Simulator::Destroy ();
  return 0;
}
