/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "ns3/core-module.h"
#include "ns3/simulator-module.h"
#include "ns3/node-module.h"
#include "ns3/helper-module.h"
#include "ns3/wifi-module.h"
#include "ns3/mobility-module.h"
#include <fstream>

#define  ADHOC

// Default Network Topology
//
//   Wifi 10.1.3.0
//                 AP   
//  *    *    *    *
//  |    |    |    |    10.1.1.0
// n5   n6   n7   n0 -------------- n1   n2   n3   n4
//                   point-to-point  |    |    |    |
//                                   ================
//                                     LAN 10.1.2.0

using namespace ns3;

NS_LOG_COMPONENT_DEFINE ("ThirdScriptExample");

int 
main (int argc, char *argv[])
{
  bool verbose = true;
  uint32_t nWifi = 60;
  uint32_t nP2p = 9;
  CommandLine cmd;
//  cmd.AddValue ("nCsma", "Number of \"extra\" CSMA nodes/devices", nCsma);
  cmd.AddValue ("nWifi", "Number of wifi STA devices", nWifi);
  cmd.AddValue ("verbose", "Tell echo applications to log if true", verbose);
  cmd.Parse (argc,argv);

  if (verbose)
    {
      LogComponentEnable("UdpEchoClientApplication", LOG_LEVEL_INFO);
      LogComponentEnable("UdpEchoServerApplication", LOG_LEVEL_INFO);
    }

  NodeContainer nC;
  nC.Create (nP2p);

  PointToPointHelper pointToPoint;
  pointToPoint.SetDeviceAttribute ("DataRate", StringValue ("100Mbps"));
  pointToPoint.SetChannelAttribute ("Delay", StringValue ("0.1ms"));

  NodeContainer p2p01 = NodeContainer (nC.Get(0), nC.Get (1));
  NodeContainer p2p02 = NodeContainer (nC.Get(0), nC.Get (2));
  NodeContainer p2p12 = NodeContainer (nC.Get(1), nC.Get (2));
  
  NodeContainer p2p34 = NodeContainer (nC.Get(3), nC.Get (4));
  NodeContainer p2p35 = NodeContainer (nC.Get(3), nC.Get (5));
  NodeContainer p2p45 = NodeContainer (nC.Get(4), nC.Get (5));
  
  NodeContainer p2p67 = NodeContainer (nC.Get(6), nC.Get (7));
  NodeContainer p2p68 = NodeContainer (nC.Get(6), nC.Get (8));
  NodeContainer p2p78 = NodeContainer (nC.Get(7), nC.Get (8));
  
  NetDeviceContainer p2pDevices01 = pointToPoint.Install (p2p01);
  NetDeviceContainer p2pDevices02 = pointToPoint.Install (p2p02);
  NetDeviceContainer p2pDevices12 = pointToPoint.Install (p2p12);
  
  NetDeviceContainer p2pDevices34 = pointToPoint.Install (p2p34);
  NetDeviceContainer p2pDevices35 = pointToPoint.Install (p2p35);
  NetDeviceContainer p2pDevices45 = pointToPoint.Install (p2p45);
  
  NetDeviceContainer p2pDevices67 = pointToPoint.Install (p2p67);
  NetDeviceContainer p2pDevices68 = pointToPoint.Install (p2p68);
  NetDeviceContainer p2pDevices78 = pointToPoint.Install (p2p78);

  NodeContainer wifiStaNodes;
  wifiStaNodes.Create (nWifi);
  NodeContainer wifiApNode = NodeContainer (nC);

  YansWifiChannelHelper channel = YansWifiChannelHelper::Default ();
  YansWifiPhyHelper phy = YansWifiPhyHelper::Default ();
  phy.SetChannel (channel.Create ());

  WifiHelper wifi = WifiHelper::Default ();
  wifi.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
                                "DataMode", StringValue ("wifia-6mbs"));

  NqosWifiMacHelper mac = NqosWifiMacHelper::Default ();

  Ssid ssid = Ssid ("ns-3-ssid");
  mac.SetType ("ns3::NqapWifiMac", 
    "Ssid", SsidValue (ssid),
    "BeaconGeneration", BooleanValue (true),
    "BeaconInterval", TimeValue (Seconds (2.5)));

  NetDeviceContainer apDevices;
  apDevices = wifi.Install (phy, mac, wifiApNode);

  mac.SetType ("ns3::NqstaWifiMac", 
    "Ssid", SsidValue (ssid),
    "ActiveProbing", BooleanValue (false));

  NetDeviceContainer staDevices;
  staDevices = wifi.Install (phy, mac, wifiStaNodes);

  MobilityHelper mobility;
  Ptr<ListPositionAllocator> positionAllocAp01 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp02 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp03 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp04 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp05 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp06 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp07 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp08 = CreateObject<ListPositionAllocator> ();
  Ptr<ListPositionAllocator> positionAllocAp09 = CreateObject<ListPositionAllocator> ();

  Ptr<BonnMotionPositionAllocator> positionAllocSta01 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta02 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta03 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta04 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta05 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta06 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta07 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta08 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta09 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta10 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta11 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta12 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta13 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta14 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta15 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta16 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta17 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta18 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta19 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta20 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta21 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta22 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta23 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta24 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta25 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta26 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta27 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta28 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta29 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta30 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta31 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta32 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta33 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta34 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta35 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta36 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta37 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta38 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta39 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta40 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta41 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta42 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta43 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta44 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta45 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta46 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta47 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta48 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta49 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta50 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta51 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta52 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta53 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta54 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta55 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta56 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta57 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta58 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta59 = CreateObject<BonnMotionPositionAllocator> ();
  Ptr<BonnMotionPositionAllocator> positionAllocSta60 = CreateObject<BonnMotionPositionAllocator> ();

  mobility.SetMobilityModel ("ns3::RandomWalk2dMobilityModel",
  			 "Mode", StringValue ("Time"),
			 "Time", StringValue ("2s"),
			 "Speed", StringValue ("Constant:0.0"),
//			 "Speed", RandomVariableValue (UniformVariable (1.0, 3.0)),
			 "Bounds", RectangleValue (Rectangle (0, 3000.0, 0.0, 3000.0)));

  positionAllocAp01->Add (Vector (100, 100, 0.0));
  mobility.SetPositionAllocator (positionAllocAp01);
  mobility.Install (wifiApNode.Get (0));

  positionAllocAp02->Add (Vector (300, 100, 0.0));      
  mobility.SetPositionAllocator (positionAllocAp02);
  mobility.Install (wifiApNode.Get (1));

  positionAllocAp03->Add (Vector (200, 300, 0.0));      
  mobility.SetPositionAllocator (positionAllocAp03);
  mobility.Install (wifiApNode.Get (2));

  positionAllocAp04->Add (Vector (2700, 100, 0.0));
  mobility.SetPositionAllocator (positionAllocAp04);
  mobility.Install (wifiApNode.Get (3));

  positionAllocAp05->Add (Vector (2900, 100, 0.0));
  mobility.SetPositionAllocator (positionAllocAp05);
  mobility.Install (wifiApNode.Get (4));

  positionAllocAp06->Add (Vector (2800, 300, 0.0));      
  mobility.SetPositionAllocator (positionAllocAp06);
  mobility.Install (wifiApNode.Get (5));

  positionAllocAp07->Add (Vector (1400, 2700, 0.0));
  mobility.SetPositionAllocator (positionAllocAp07);
  mobility.Install (wifiApNode.Get (6));

  positionAllocAp08->Add (Vector (1600, 2700, 0.0));
  mobility.SetPositionAllocator (positionAllocAp08);
  mobility.Install (wifiApNode.Get (7));

  positionAllocAp09->Add (Vector (1500, 2900, 0.0));
  mobility.SetPositionAllocator (positionAllocAp09);
  mobility.Install (wifiApNode.Get (8));


  positionAllocSta01->SetAttribute ("FileNumber", UintegerValue (1));
  positionAllocSta01->Add (Vector (130, 370, 0.0));
  positionAllocSta01->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta01);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta01)
                            );
  mobility.Install (wifiStaNodes.Get (0));

  
  positionAllocSta02->SetAttribute ("FileNumber", UintegerValue (2));
  positionAllocSta02->Add (Vector (330, 170, 0.0));
  positionAllocSta02->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta02);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta02)
                            );
  mobility.Install (wifiStaNodes.Get (1));

  
  positionAllocSta03->SetAttribute ("FileNumber", UintegerValue (3));
  positionAllocSta03->Add (Vector (230, 270, 0.0));
  positionAllocSta03->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta03);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta03)
                            );
  mobility.Install (wifiStaNodes.Get (2));
  

  positionAllocSta04->SetAttribute ("FileNumber", UintegerValue (4));
  positionAllocSta04->Add (Vector (250, 310, 0.0));
  positionAllocSta04->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta04);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta04)
                            );
  mobility.Install (wifiStaNodes.Get (3));
  

  positionAllocSta05->SetAttribute ("FileNumber", UintegerValue (5));
  positionAllocSta05->Add (Vector (30, 215, 0.0));
  positionAllocSta05->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta05);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta05)
                            );
  mobility.Install (wifiStaNodes.Get (4));


  positionAllocSta06->SetAttribute ("FileNumber", UintegerValue (6));
  positionAllocSta06->Add (Vector (370, 310, 0.0));
  positionAllocSta06->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta06);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta06)
                            );
  mobility.Install (wifiStaNodes.Get (5));
  

  positionAllocSta07->SetAttribute ("FileNumber", UintegerValue (7));
  positionAllocSta07->Add (Vector (130, 370, 0.0));
  positionAllocSta07->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta07);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta07)
                            );
  mobility.Install (wifiStaNodes.Get (6));
  
  
  positionAllocSta08->SetAttribute ("FileNumber", UintegerValue (8));
  positionAllocSta08->Add (Vector (310, 120, 0.0));
  positionAllocSta08->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta08);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta08)
                            );
  mobility.Install (wifiStaNodes.Get (7));
  
  
  positionAllocSta09->SetAttribute ("FileNumber", UintegerValue (9));
  positionAllocSta09->Add (Vector (230, 350, 0.0));
  positionAllocSta09->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta09);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta09)
                            );
  mobility.Install (wifiStaNodes.Get (8));
  
  
  positionAllocSta10->SetAttribute ("FileNumber", UintegerValue (10));
  positionAllocSta10->Add (Vector (70, 210, 0.0));
  positionAllocSta10->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta10);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta10)
                            );
  mobility.Install (wifiStaNodes.Get (9));
  
  
  positionAllocSta11->SetAttribute ("FileNumber", UintegerValue (11));
  positionAllocSta11->Add (Vector (120, 80, 0.0));
  positionAllocSta11->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta11);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta11)
                            );
  mobility.Install (wifiStaNodes.Get (10));
  
  
  positionAllocSta12->SetAttribute ("FileNumber", UintegerValue (12));
  positionAllocSta12->Add (Vector (300, 50, 0.0));
  positionAllocSta12->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta12);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta12)
                            );
  mobility.Install (wifiStaNodes.Get (11));
  
  
  positionAllocSta13->SetAttribute ("FileNumber", UintegerValue (13));
  positionAllocSta13->Add (Vector (180, 160, 0.0));
  positionAllocSta13->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta13);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta13)
                            );
  mobility.Install (wifiStaNodes.Get (12));
  
  
  positionAllocSta14->SetAttribute ("FileNumber", UintegerValue (14));
  positionAllocSta14->Add (Vector (330, 370, 0.0));
  positionAllocSta14->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta14);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta14)
                            );
  mobility.Install (wifiStaNodes.Get (13));
  
  
  positionAllocSta15->SetAttribute ("FileNumber", UintegerValue (15));
  positionAllocSta15->Add (Vector (1234, 134, 0.0));
  positionAllocSta15->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta15);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta15)
                            );
  mobility.Install (wifiStaNodes.Get (14));
  
  
  positionAllocSta16->SetAttribute ("FileNumber", UintegerValue (16));
  positionAllocSta16->Add (Vector (521, 145, 0.0));
  positionAllocSta16->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta16);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta16)
                            );
  mobility.Install (wifiStaNodes.Get (15));
  
  
  positionAllocSta17->SetAttribute ("FileNumber", UintegerValue (17));
  positionAllocSta17->Add (Vector (198, 423, 0.0));
  positionAllocSta17->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta17);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta17)
                            );
  mobility.Install (wifiStaNodes.Get (16));
  
  
  positionAllocSta18->SetAttribute ("FileNumber", UintegerValue (18));
  positionAllocSta18->Add (Vector (1694, 86, 0.0));
  positionAllocSta18->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta18);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta18)
                            );
  mobility.Install (wifiStaNodes.Get (17));
  

  positionAllocSta19->SetAttribute ("FileNumber", UintegerValue (19));
  positionAllocSta19->Add (Vector (655, 866, 0.0));
  positionAllocSta19->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta19);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta19)
                            );
  mobility.Install (wifiStaNodes.Get (18));
  
  
  positionAllocSta20->SetAttribute ("FileNumber", UintegerValue (20));
  positionAllocSta20->Add (Vector (1316, 211, 0.0));
  positionAllocSta20->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta20);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta20)
                            );
  mobility.Install (wifiStaNodes.Get (19));
  
  
  positionAllocSta21->SetAttribute ("FileNumber", UintegerValue (21));
  positionAllocSta21->Add (Vector (2701, 101, 0.0));
  positionAllocSta21->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta21);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta21)
                            );
  mobility.Install (wifiStaNodes.Get (20));


  positionAllocSta22->SetAttribute ("FileNumber", UintegerValue (22));
  positionAllocSta22->Add (Vector (2807, 140, 0.0));
  positionAllocSta22->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta22);  
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta22)
                            );
  mobility.Install (wifiStaNodes.Get (21));


  positionAllocSta23->SetAttribute ("FileNumber", UintegerValue (23));
  positionAllocSta23->Add (Vector (2899, 129, 0.0));
  positionAllocSta23->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta23);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta23)
                            );
  mobility.Install (wifiStaNodes.Get (22));
  

  positionAllocSta24->SetAttribute ("FileNumber", UintegerValue (24));
  positionAllocSta24->Add (Vector (2881, 276, 0.0));
  positionAllocSta24->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta24);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta24)
                            );
  mobility.Install (wifiStaNodes.Get (23));


  positionAllocSta25->SetAttribute ("FileNumber", UintegerValue (25));
  positionAllocSta25->Add (Vector (2815, 220, 0.0));
  positionAllocSta25->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta25);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta25)
                            );
  mobility.Install (wifiStaNodes.Get (24));
 

  positionAllocSta26->SetAttribute ("FileNumber", UintegerValue (26));
  positionAllocSta26->Add (Vector (2765, 190, 0.0));
  positionAllocSta26->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta26);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta26)
                            );
  mobility.Install (wifiStaNodes.Get (25));


  positionAllocSta27->SetAttribute ("FileNumber", UintegerValue (27));
  positionAllocSta27->Add (Vector (2995, 85, 0.0));
  positionAllocSta27->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta27);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta27)
                            );
  mobility.Install (wifiStaNodes.Get (26));

  
  positionAllocSta28->SetAttribute ("FileNumber", UintegerValue (28));
  positionAllocSta28->Add (Vector (2765, 320, 0.0));
  positionAllocSta28->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta28);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta28)
                            );
  mobility.Install (wifiStaNodes.Get (27));


  positionAllocSta29->SetAttribute ("FileNumber", UintegerValue (29));
  positionAllocSta29->Add (Vector (2695, 180, 0.0));
  positionAllocSta29->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta29);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta29)
                            );
  mobility.Install (wifiStaNodes.Get (28));


  positionAllocSta30->SetAttribute ("FileNumber", UintegerValue (30));
  positionAllocSta30->Add (Vector (2915, 290, 0.0));
  positionAllocSta30->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta30);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta30)
                            );
  mobility.Install (wifiStaNodes.Get (29));


  positionAllocSta31->SetAttribute ("FileNumber", UintegerValue (31));
  positionAllocSta31->Add (Vector (2685, 230, 0.0));
  positionAllocSta31->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta31);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta31)
                            );
  mobility.Install (wifiStaNodes.Get (30));


  positionAllocSta32->SetAttribute ("FileNumber", UintegerValue (32));
  positionAllocSta32->Add (Vector (2745, 130, 0.0));
  positionAllocSta32->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta32);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta32)
                            );
  mobility.Install (wifiStaNodes.Get (31));


  positionAllocSta33->SetAttribute ("FileNumber", UintegerValue (33));
  positionAllocSta33->Add (Vector (2825, 320, 0.0));
  positionAllocSta33->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta33);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta33)
                            );
  mobility.Install (wifiStaNodes.Get (32));
  

  positionAllocSta34->SetAttribute ("FileNumber", UintegerValue (34));
  positionAllocSta34->Add (Vector (2790, 250, 0.0));
  positionAllocSta34->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta34);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta34)
                            );
  mobility.Install (wifiStaNodes.Get (33));


  positionAllocSta35->SetAttribute ("FileNumber", UintegerValue (35));
  positionAllocSta35->Add (Vector (2554, 756, 0.0));
  positionAllocSta35->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta35);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta35)
                            );
  mobility.Install (wifiStaNodes.Get (34));


  positionAllocSta36->SetAttribute ("FileNumber", UintegerValue (36));
  positionAllocSta36->Add (Vector (1483, 2604, 0.0));
  positionAllocSta36->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta36);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta36)
                            );
  mobility.Install (wifiStaNodes.Get (35));


  positionAllocSta37->SetAttribute ("FileNumber", UintegerValue (37));
  positionAllocSta37->Add (Vector (1505, 2379, 0.0));
  positionAllocSta37->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta37);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta37)
                            );
  mobility.Install (wifiStaNodes.Get (36));
  

  positionAllocSta38->SetAttribute ("FileNumber", UintegerValue (38));
  positionAllocSta38->Add (Vector (2250, 105, 0.0));
  positionAllocSta38->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta38);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta38)
                            );
  mobility.Install (wifiStaNodes.Get (37));


  positionAllocSta39->SetAttribute ("FileNumber", UintegerValue (39));
  positionAllocSta39->Add (Vector (1818, 2322, 0.0));
  positionAllocSta39->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta39);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta39)
                            );
  mobility.Install (wifiStaNodes.Get (38));


  positionAllocSta40->SetAttribute ("FileNumber", UintegerValue (40));
  positionAllocSta40->Add (Vector (2821, 68, 0.0));
  positionAllocSta40->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta40);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta40)
                            );
  mobility.Install (wifiStaNodes.Get (39));
  
  
  positionAllocSta41->SetAttribute ("FileNumber", UintegerValue (41));
  positionAllocSta41->Add (Vector (1585, 2930, 0.0));
  positionAllocSta41->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta41);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta41)
                            );
  mobility.Install (wifiStaNodes.Get (40));


  positionAllocSta42->SetAttribute ("FileNumber", UintegerValue (42));
  positionAllocSta42->Add (Vector (1615, 2980, 0.0));
  positionAllocSta42->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta42);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta42)
                            );
  mobility.Install (wifiStaNodes.Get (41));


  positionAllocSta43->SetAttribute ("FileNumber", UintegerValue (43));
  positionAllocSta43->Add (Vector (1525, 2790, 0.0));
  positionAllocSta43->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta43);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta43)
                            );
  mobility.Install (wifiStaNodes.Get (42));
  

  positionAllocSta44->SetAttribute ("FileNumber", UintegerValue (44));
  positionAllocSta44->Add (Vector (1590, 2850, 0.0));
  positionAllocSta44->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta44);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta44)
                            );
  mobility.Install (wifiStaNodes.Get (43));


  positionAllocSta45->SetAttribute ("FileNumber", UintegerValue (45));
  positionAllocSta45->Add (Vector (1315, 2680, 0.0));
  positionAllocSta45->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta45);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta45)
                            );
  mobility.Install (wifiStaNodes.Get (44));


  positionAllocSta46->SetAttribute ("FileNumber", UintegerValue (46));
  positionAllocSta46->Add (Vector (1450, 2890, 0.0));
  positionAllocSta46->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta46);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta46)
                            );
  mobility.Install (wifiStaNodes.Get (45));


  positionAllocSta47->SetAttribute ("FileNumber", UintegerValue (47));
  positionAllocSta47->Add (Vector (1595, 2825, 0.0));
  positionAllocSta47->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta47);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta47)
                            );
  mobility.Install (wifiStaNodes.Get (46));
  

  positionAllocSta48->SetAttribute ("FileNumber", UintegerValue (48));
  positionAllocSta48->Add (Vector (1325, 2980, 0.0));
  positionAllocSta48->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta48);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta48)
                            );
  mobility.Install (wifiStaNodes.Get (47));


  positionAllocSta49->SetAttribute ("FileNumber", UintegerValue (49));
  positionAllocSta49->Add (Vector (1695, 2780, 0.0));
  positionAllocSta49->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta49);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta49)
                            );
  mobility.Install (wifiStaNodes.Get (48));


  positionAllocSta50->SetAttribute ("FileNumber", UintegerValue (50));
  positionAllocSta50->Add (Vector (1515, 2690, 0.0));
  positionAllocSta50->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta50);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta50)
                            );
  mobility.Install (wifiStaNodes.Get (49));
  
  
  positionAllocSta51->SetAttribute ("FileNumber", UintegerValue (51));
  positionAllocSta51->Add (Vector (1685, 2730, 0.0));
  positionAllocSta51->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta51);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta51)
                            );
  mobility.Install (wifiStaNodes.Get (50));


  positionAllocSta52->SetAttribute ("FileNumber", UintegerValue (52));
  positionAllocSta52->Add (Vector (1615, 2850, 0.0));
  positionAllocSta52->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta52);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta52)
                            );
  mobility.Install (wifiStaNodes.Get (51));


  positionAllocSta53->SetAttribute ("FileNumber", UintegerValue (53));
  positionAllocSta53->Add (Vector (1425, 2990, 0.0));
  positionAllocSta53->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta53);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta53)
                            );
  mobility.Install (wifiStaNodes.Get (52));
  

  positionAllocSta54->SetAttribute ("FileNumber", UintegerValue (54));
  positionAllocSta54->Add (Vector (1390, 2650, 0.0));
  positionAllocSta54->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta54);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta54)
                            );
  mobility.Install (wifiStaNodes.Get (53));


  positionAllocSta55->SetAttribute ("FileNumber", UintegerValue (55));
  positionAllocSta55->Add (Vector (1204, 2444, 0.0));
  positionAllocSta55->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta55);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta55)
                            );
  mobility.Install (wifiStaNodes.Get (54));


  positionAllocSta56->SetAttribute ("FileNumber", UintegerValue (56));
  positionAllocSta56->Add (Vector (2192, 1391, 0.0));
  positionAllocSta56->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta56);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta56)
                            );
  mobility.Install (wifiStaNodes.Get (55));


  positionAllocSta57->SetAttribute ("FileNumber", UintegerValue (57));
  positionAllocSta57->Add (Vector (2228, 1437, 0.0));
  positionAllocSta57->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta57);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta57)
                            );
  mobility.Install (wifiStaNodes.Get (56));
  

  positionAllocSta58->SetAttribute ("FileNumber", UintegerValue (58));
  positionAllocSta58->Add (Vector (199, 170, 0.0));
  positionAllocSta58->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta58);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta58)
                            );
  mobility.Install (wifiStaNodes.Get (57));


  positionAllocSta59->SetAttribute ("FileNumber", UintegerValue (59));
  positionAllocSta59->Add (Vector (1996, 1917, 0.0));
  positionAllocSta59->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta59);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta59)
                            );
  mobility.Install (wifiStaNodes.Get (58));


  positionAllocSta60->SetAttribute ("FileNumber", UintegerValue (60));
  positionAllocSta60->Add (Vector (1708, 2108, 0.0));
  positionAllocSta60->ParseFile ();
  mobility.SetPositionAllocator (positionAllocSta60);
  mobility.SetMobilityModel ("ns3::BonnMotionMobilityModel",
                             "PositionAllocator", PointerValue (positionAllocSta60)
                            );
  mobility.Install (wifiStaNodes.Get (59));

#ifdef ADHOC
  NodeContainer adhoc (wifiStaNodes);
  WifiHelper wifiAdhoc;
  NqosWifiMacHelper macAdhoc = NqosWifiMacHelper::Default ();
  macAdhoc.SetType ("ns3::AdhocWifiMac");
  wifiAdhoc.SetRemoteStationManager ("ns3::ConstantRateWifiManager",
                                "DataMode", StringValue ("wifia-6mbs"));
  YansWifiPhyHelper wifiAdhocPhy = YansWifiPhyHelper::Default ();
  YansWifiChannelHelper wifiAdhocChannel = YansWifiChannelHelper::Default ();
  wifiAdhocPhy.SetChannel (wifiAdhocChannel.Create ());
  NetDeviceContainer adhocDevices = wifiAdhoc.Install (wifiAdhocPhy, macAdhoc, adhoc);
#endif

  InternetStackHelper stack;
  static MeDeHaDtnRoutingHelper mdrouting;
  stack.Install (wifiApNode);

  static Ipv4GlobalRoutingHelper globalRouting;
  static Ipv4ListRoutingHelper listRouting;
  listRouting.Add (mdrouting, 0);
  listRouting.Add (globalRouting, -10);
  stack.SetRoutingHelper (listRouting);

//  stack.SetRoutingHelper (mdrouting);
//  stack.Install (adhoc);
  stack.Install (wifiStaNodes);  

  Ipv4AddressHelper address;


  Ipv4InterfaceContainer p2pInterfaces01, p2pInterfaces02, p2pInterfaces12;
  Ipv4InterfaceContainer p2pInterfaces34, p2pInterfaces35, p2pInterfaces45;
  Ipv4InterfaceContainer p2pInterfaces67, p2pInterfaces68, p2pInterfaces78;

  address.SetBase ("10.1.3.0", "255.255.255.0");
  p2pInterfaces01 = address.Assign (p2pDevices01);
  address.SetBase ("11.1.3.0", "255.255.255.0");
  p2pInterfaces02 = address.Assign (p2pDevices02);
  address.SetBase ("12.1.3.0", "255.255.255.0");
  p2pInterfaces12 = address.Assign (p2pDevices12);
  address.SetBase ("13.1.3.0", "255.255.255.0");
  p2pInterfaces34 = address.Assign (p2pDevices34);
  address.SetBase ("14.1.3.0", "255.255.255.0");
  p2pInterfaces35 = address.Assign (p2pDevices35);
  address.SetBase ("15.1.3.0", "255.255.255.0");
  p2pInterfaces45 = address.Assign (p2pDevices45);
  address.SetBase ("16.1.3.0", "255.255.255.0");
  p2pInterfaces67 = address.Assign (p2pDevices67);
  address.SetBase ("17.1.3.0", "255.255.255.0");
  p2pInterfaces68 = address.Assign (p2pDevices68);
  address.SetBase ("18.1.3.0", "255.255.255.0");
  p2pInterfaces78 = address.Assign (p2pDevices78);  

#ifdef ADHOC
  address.SetBase ("192.168.6.0", "255.255.255.0");
  Ipv4InterfaceContainer adhocInterfaces;
  adhocInterfaces = address.Assign (adhocDevices);
#endif

  address.SetBase ("10.1.1.0", "255.255.255.0");
  Ipv4InterfaceContainer apInterfaces = address.Assign (apDevices);
  Ipv4InterfaceContainer staInterfaces = address.Assign (staDevices);


  Address dest01, dest02, dest03, dest04, dest05, dest06, dest07, dest08, dest09, dest10;
  Address dest11, dest12, dest13, dest14, dest15, dest16, dest17, dest18, dest19, dest20;
  std::string protocol;

  dest01 = InetSocketAddress (staInterfaces.GetAddress (0), 1025);
  dest02 = InetSocketAddress (staInterfaces.GetAddress (1), 1035);
  dest03 = InetSocketAddress (staInterfaces.GetAddress (2), 1045);
  dest04 = InetSocketAddress (staInterfaces.GetAddress (3), 1055);
  dest05 = InetSocketAddress (staInterfaces.GetAddress (20), 1065);
  dest06 = InetSocketAddress (staInterfaces.GetAddress (21), 1075);
  dest07 = InetSocketAddress (staInterfaces.GetAddress (22), 1085);
  dest08 = InetSocketAddress (staInterfaces.GetAddress (40), 1095);
  dest09 = InetSocketAddress (staInterfaces.GetAddress (41), 1105);
  dest10 = InetSocketAddress (staInterfaces.GetAddress (42), 1115);
  dest11 = InetSocketAddress (staInterfaces.GetAddress (8), 1125);
  dest12 = InetSocketAddress (staInterfaces.GetAddress (10), 1135);
  dest13 = InetSocketAddress (staInterfaces.GetAddress (12), 1145);
  dest14 = InetSocketAddress (staInterfaces.GetAddress (24), 1155);
  dest15 = InetSocketAddress (staInterfaces.GetAddress (26), 1165);
  dest16 = InetSocketAddress (staInterfaces.GetAddress (28), 1175);
  dest17 = InetSocketAddress (staInterfaces.GetAddress (30), 1185);
  dest18 = InetSocketAddress (staInterfaces.GetAddress (48), 1195);
  dest19 = InetSocketAddress (staInterfaces.GetAddress (50), 1205);
  dest20 = InetSocketAddress (staInterfaces.GetAddress (52), 1215);

  protocol = "ns3::UdpSocketFactory";

  OnOffHelper onoff01 = OnOffHelper (protocol, dest01);
  OnOffHelper onoff02 = OnOffHelper (protocol, dest02);
  OnOffHelper onoff03 = OnOffHelper (protocol, dest03);
  OnOffHelper onoff04 = OnOffHelper (protocol, dest04);
  OnOffHelper onoff05 = OnOffHelper (protocol, dest05);
  OnOffHelper onoff06 = OnOffHelper (protocol, dest06);
  OnOffHelper onoff07 = OnOffHelper (protocol, dest07);
  OnOffHelper onoff08 = OnOffHelper (protocol, dest08);
  OnOffHelper onoff09 = OnOffHelper (protocol, dest09);
  OnOffHelper onoff10 = OnOffHelper (protocol, dest10);
  OnOffHelper onoff11 = OnOffHelper (protocol, dest11);
  OnOffHelper onoff12 = OnOffHelper (protocol, dest12);
  OnOffHelper onoff13 = OnOffHelper (protocol, dest13);
  OnOffHelper onoff14 = OnOffHelper (protocol, dest14);
  OnOffHelper onoff15 = OnOffHelper (protocol, dest15);
  OnOffHelper onoff16 = OnOffHelper (protocol, dest16);
  OnOffHelper onoff17 = OnOffHelper (protocol, dest17);
  OnOffHelper onoff18 = OnOffHelper (protocol, dest18);
  OnOffHelper onoff19 = OnOffHelper (protocol, dest19);
  OnOffHelper onoff20 = OnOffHelper (protocol, dest20);
    

  onoff01.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff02.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff03.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff04.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff05.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff06.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff07.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff08.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff09.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff10.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff11.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff12.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff13.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff14.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff15.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff16.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff17.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff18.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff19.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  onoff20.SetAttribute ("OnTime", RandomVariableValue (ConstantVariable (1)));
  
  
  onoff01.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff02.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff03.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff04.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff05.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff06.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff07.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff08.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff09.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff10.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff11.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff12.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff13.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff14.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff15.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff16.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff17.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff18.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff19.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  onoff20.SetAttribute ("OffTime", RandomVariableValue (ConstantVariable (0)));
  
  
  onoff01.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff02.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff03.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff04.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff05.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff06.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff07.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff08.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff09.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff10.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff11.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff12.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff13.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff14.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff15.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff16.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff17.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff18.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));  
  onoff19.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));
  onoff20.SetAttribute ("DataRate", DataRateValue (DataRate ("200bps")));


  ApplicationContainer apps00 = onoff01.Install (wifiStaNodes.Get (1));
  ApplicationContainer apps10 = onoff02.Install (wifiStaNodes.Get (0));
  ApplicationContainer apps20 = onoff03.Install (wifiStaNodes.Get (3));
  ApplicationContainer apps30 = onoff04.Install (wifiStaNodes.Get (2));
  ApplicationContainer apps40 = onoff05.Install (wifiStaNodes.Get (21));  
  ApplicationContainer apps50 = onoff06.Install (wifiStaNodes.Get (20));
  ApplicationContainer apps60 = onoff07.Install (wifiStaNodes.Get (23));
  ApplicationContainer apps70 = onoff08.Install (wifiStaNodes.Get (41));
  ApplicationContainer apps80 = onoff09.Install (wifiStaNodes.Get (40));
  ApplicationContainer apps90 = onoff10.Install (wifiStaNodes.Get (43));
  ApplicationContainer apps100 = onoff11.Install (wifiStaNodes.Get (25));
  ApplicationContainer apps110 = onoff12.Install (wifiStaNodes.Get (46));
  ApplicationContainer apps120 = onoff13.Install (wifiStaNodes.Get (31));
  ApplicationContainer apps130 = onoff14.Install (wifiStaNodes.Get (7));
  ApplicationContainer apps140 = onoff15.Install (wifiStaNodes.Get (47));
  ApplicationContainer apps150 = onoff16.Install (wifiStaNodes.Get (9));
  ApplicationContainer apps160 = onoff17.Install (wifiStaNodes.Get (49));
  ApplicationContainer apps170 = onoff18.Install (wifiStaNodes.Get (11));
  ApplicationContainer apps180 = onoff19.Install (wifiStaNodes.Get (29));
  ApplicationContainer apps190 = onoff20.Install (wifiStaNodes.Get (13));  
  
  
  apps00.Start (Seconds (320.0));
  apps10.Start (Seconds (320.0));
  apps20.Start (Seconds (320.0));
  apps30.Start (Seconds (320.0));
  apps40.Start (Seconds (320.0));
  apps50.Start (Seconds (320.0));
  apps60.Start (Seconds (320.0));
  apps70.Start (Seconds (320.0));
  apps80.Start (Seconds (320.0));
  apps90.Start (Seconds (320.0));
  apps100.Start (Seconds (320.0));
  apps110.Start (Seconds (320.0));
  apps120.Start (Seconds (320.0));
  apps130.Start (Seconds (320.0));
  apps140.Start (Seconds (320.0));
  apps150.Start (Seconds (320.0));
  apps160.Start (Seconds (320.0));
  apps170.Start (Seconds (320.0));
  apps180.Start (Seconds (320.0));
  apps190.Start (Seconds (320.0));
  
  
  apps00.Stop (Seconds (4999.0)); 
  apps10.Stop (Seconds (4999.0)); 
  apps20.Stop (Seconds (4999.0)); 
  apps30.Stop (Seconds (4999.0)); 
  apps40.Stop (Seconds (4999.0)); 
  apps50.Stop (Seconds (4999.0)); 
  apps60.Stop (Seconds (4999.0)); 
  apps70.Stop (Seconds (4999.0)); 
  apps80.Stop (Seconds (4999.0)); 
  apps90.Stop (Seconds (4999.0)); 
  apps100.Stop (Seconds (4999.0));
  apps110.Stop (Seconds (4999.0));
  apps120.Stop (Seconds (4999.0));
  apps130.Stop (Seconds (4999.0));
  apps140.Stop (Seconds (4999.0));
  apps150.Stop (Seconds (4999.0));
  apps160.Stop (Seconds (4999.0));
  apps170.Stop (Seconds (4999.0));
  apps180.Stop (Seconds (4999.0));
  apps190.Stop (Seconds (4999.0));

  

  // Create a packet sink to receive these packets
  PacketSinkHelper sink01 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1025));
  PacketSinkHelper sink02 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1035));
  PacketSinkHelper sink03 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1045));
  PacketSinkHelper sink04 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1055));
  PacketSinkHelper sink05 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1065));
  PacketSinkHelper sink06 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1075));
  PacketSinkHelper sink07 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1085));
  PacketSinkHelper sink08 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1095));
  PacketSinkHelper sink09 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1105));
  PacketSinkHelper sink10 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1115));
  PacketSinkHelper sink11 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1125));
  PacketSinkHelper sink12 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1135));
  PacketSinkHelper sink13 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1145));
  PacketSinkHelper sink14 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1155));
  PacketSinkHelper sink15 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1165));
  PacketSinkHelper sink16 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1175));
  PacketSinkHelper sink17 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1185));
  PacketSinkHelper sink18 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1195));
  PacketSinkHelper sink19 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1205));
  PacketSinkHelper sink20 ("ns3::UdpSocketFactory", InetSocketAddress (Ipv4Address::GetAny (), 1215));


  ApplicationContainer apps01 = sink01.Install (wifiStaNodes.Get (0));
  ApplicationContainer apps11 = sink02.Install (wifiStaNodes.Get (1));
  ApplicationContainer apps21 = sink03.Install (wifiStaNodes.Get (2));
  ApplicationContainer apps31 = sink04.Install (wifiStaNodes.Get (3));
  ApplicationContainer apps41 = sink05.Install (wifiStaNodes.Get (20));
  ApplicationContainer apps51 = sink06.Install (wifiStaNodes.Get (21));
  ApplicationContainer apps61 = sink07.Install (wifiStaNodes.Get (22));
  ApplicationContainer apps71 = sink08.Install (wifiStaNodes.Get (40));
  ApplicationContainer apps81 = sink09.Install (wifiStaNodes.Get (41));
  ApplicationContainer apps91 = sink10.Install (wifiStaNodes.Get (42));
  ApplicationContainer apps101 = sink11.Install (wifiStaNodes.Get (8));
  ApplicationContainer apps111 = sink12.Install (wifiStaNodes.Get (10));
  ApplicationContainer apps121 = sink13.Install (wifiStaNodes.Get (12));
  ApplicationContainer apps131 = sink14.Install (wifiStaNodes.Get (24));
  ApplicationContainer apps141 = sink15.Install (wifiStaNodes.Get (26));
  ApplicationContainer apps151 = sink16.Install (wifiStaNodes.Get (28));
  ApplicationContainer apps161 = sink17.Install (wifiStaNodes.Get (30));
  ApplicationContainer apps171 = sink18.Install (wifiStaNodes.Get (48));
  ApplicationContainer apps181 = sink19.Install (wifiStaNodes.Get (50));
  ApplicationContainer apps191 = sink20.Install (wifiStaNodes.Get (52));


  apps01.Start (Seconds (2.0));
  apps11.Start (Seconds (2.0));
  apps21.Start (Seconds (2.0));
  apps31.Start (Seconds (2.0));
  apps41.Start (Seconds (2.0));
  apps51.Start (Seconds (2.0));
  apps61.Start (Seconds (2.0));
  apps71.Start (Seconds (2.0));
  apps81.Start (Seconds (2.0));
  apps91.Start (Seconds (2.0));
  apps101.Start (Seconds (2.0));
  apps111.Start (Seconds (2.0));
  apps121.Start (Seconds (2.0));
  apps131.Start (Seconds (2.0));
  apps141.Start (Seconds (2.0));
  apps151.Start (Seconds (2.0));
  apps161.Start (Seconds (2.0));
  apps171.Start (Seconds (2.0));
  apps181.Start (Seconds (2.0));
  apps191.Start (Seconds (2.0));


  apps01.Stop (Seconds (7195.0));
  apps11.Stop (Seconds (7195.0));
  apps21.Stop (Seconds (7195.0));
  apps31.Stop (Seconds (7195.0));
  apps41.Stop (Seconds (7195.0));
  apps51.Stop (Seconds (7195.0));
  apps61.Stop (Seconds (7195.0));
  apps71.Stop (Seconds (7195.0));
  apps81.Stop (Seconds (7195.0));
  apps91.Stop (Seconds (7195.0));
  apps101.Stop (Seconds (7195.0));
  apps111.Stop (Seconds (7195.0));
  apps121.Stop (Seconds (7195.0));
  apps131.Stop (Seconds (7195.0));
  apps141.Stop (Seconds (7195.0));
  apps151.Stop (Seconds (7195.0));
  apps161.Stop (Seconds (7195.0));
  apps171.Stop (Seconds (7195.0));
  apps181.Stop (Seconds (7195.0));
  apps191.Stop (Seconds (7195.0));  


  Ipv4GlobalRoutingHelper::PopulateRoutingTables ();
//  phy.EnablePcapAll ("test-medeha");

//  std::cout << "Src 01 Address = " << staInterfaces01.GetAddress (0) << "\n";
//  std::cout << "Dst 01 Address = " << staInterfaces02.GetAddress (0) << "\n";
//  std::cout << "Sta 01 Address = " << staInterfaces02.GetAddress (0) << "\n";
//  std::cout << "Sta 02 Address = " << staInterfaces02.GetAddress (1) << "\n";
//  std::cout << "P2P 01 Address = " << p2pInterfaces01.GetAddress (0) << "\n";
//  std::cout << "P2P 02 Address = " << p2pInterfaces01.GetAddress (1) << "\n";
//  std::cout << "AP 01 Address = " << apInterfaces.GetAddress (0) << "\n";
//  std::cout << "AP 02 Address = " << apInterfaces.GetAddress (1) << "\n";

  std::ofstream os;
  os.open ("test-medeha.mob");
  MobilityHelper::EnableAsciiAll (os);

//   std::ofstream phyTr;
//   phyTr.open ("test-medeha-phy.tr");
//   YansWifiPhyHelper::EnableAsciiAll (phyTr);

  Simulator::Stop (Seconds (7200.0));

  Simulator::Run ();
  Simulator::Destroy ();
  return 0;
}
