/* -*-  Mode: C++; c-file-style: "gnu"; indent-tabs-mode:nil; -*- */
/*
 * Copyright (c) 2010 INRIA
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as 
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Rao Naveed Bin Rais <Naveed-Bin.Rais@inria.fr>
 */

#include "medeha-handle-notification-ip.h"
#include "ns3/address-utils.h"
#include "ns3/log.h"
#include "ns3/simulator.h"

#define   DEBUG

//NS_LOG_COMPONENT_DEFINE ("MedehaIntraManetNotifHeader");
NS_LOG_COMPONENT_DEFINE ("MedehaHandleNotification");

namespace ns3 {


MedehaIntraManetNotifHeader::MedehaIntraManetNotifHeader ()
  : m_type (0),
    m_protocol (0)
{}

MedehaIntraManetNotifHeader::~MedehaIntraManetNotifHeader ()
{}

TypeId 
MedehaIntraManetNotifHeader::GetTypeId (void)
{
  static TypeId tid = TypeId ("ns3::MedehaIntraManetNotifHeader")
    .SetParent<Header> ()
    .AddConstructor<MedehaIntraManetNotifHeader> ()
    ;
  return tid;
}

TypeId 
MedehaIntraManetNotifHeader::GetInstanceTypeId (void) const
{
  return GetTypeId ();
}

void 
MedehaIntraManetNotifHeader::Print (std::ostream &os) const
{
 
}

uint32_t 
MedehaIntraManetNotifHeader::GetSerializedSize (void) const
{
  return 8;
//  return GetSize ();
}

void 
MedehaIntraManetNotifHeader::Serialize (Buffer::Iterator i) const
{
  i.WriteU16 (m_type);
  i.WriteU16 (m_protocol);
  i.WriteU32 (m_dstIPAddress.Get ());
}

uint32_t
MedehaIntraManetNotifHeader::Deserialize (Buffer::Iterator start)
{
  Buffer::Iterator i = start;

  m_type = i.ReadU16 ();
  m_protocol = i.ReadU16 ();
  m_dstIPAddress = (Ipv4Address) i.ReadU32 ();
  
  return i.GetDistanceFrom (start);
}



APNotifL3Header::APNotifL3Header ()
  : m_msgID (0),
    m_numOfIfces (0),
    m_manetConnection (0)
{}

APNotifL3Header::~APNotifL3Header ()
{}

TypeId 
APNotifL3Header::GetTypeId (void)
{
  static TypeId tid = TypeId ("ns3::APNotifL3Header")
    .SetParent<Header> ()
    .AddConstructor<APNotifL3Header> ()
    ;
  return tid;
}

TypeId 
APNotifL3Header::GetInstanceTypeId (void) const
{
  return GetTypeId ();
}

void 
APNotifL3Header::Print (std::ostream &os) const
{
  switch (m_msgID)
    {
    case ASS_NOTIF:
      break;
    
    case DISASS_NOTIF:
      break;
    
    case DEST_FOUND_NOTIF:
      break;
    
    case REMOVE_FRAMES_NOTIF:
      break;
    
    case UPDATE_FRAMES_NOTIF:
      break;
    
    case STORE_FRAMES_NOTIF:
      break;
    
    case FETCH_FRAMES_NOTIF:
      break;
      
    case NEIGHBORHOOD_INFO_NOTIF:
      break;
      
    case INDIRECT_ASSOCIATION_NOTIF:
      break;
    }
}

uint32_t 
APNotifL3Header::GetSerializedSize (void) const
{
  switch (m_numOfIfces)
    {
    case 1:
      return 18;
      break;
      
    case 2:
      return 22;
      break;
      
    case 3:
      return 26;
      break;
      
    default:
      return 22;
    }
//  return GetSize ();
}

void 
APNotifL3Header::Serialize (Buffer::Iterator i) const
{
  i.WriteU32 (m_msgID);
  i.WriteU32 (m_numOfIfces);

  WriteTo (i, m_srcIPAddress);
  WriteTo (i, m_IPAddress[0]);
  
  if (m_numOfIfces >= 2)
      WriteTo (i, m_IPAddress[1]);
  if (m_numOfIfces >= 3)
      WriteTo (i, m_IPAddress[2]);
      
  i.WriteU16 (m_manetConnection);
}

uint32_t
APNotifL3Header::Deserialize (Buffer::Iterator start)
{
  Buffer::Iterator i = start;
  m_msgID = i.ReadU32 ();

  m_numOfIfces = i.ReadU32 ();
  ReadFrom (i, m_srcIPAddress);
  ReadFrom (i, m_IPAddress[0]);
  
  if (m_numOfIfces >= 2)
      ReadFrom (i, m_IPAddress[1]);
  if (m_numOfIfces >= 3)
      ReadFrom (i, m_IPAddress[2]);
      
  m_manetConnection = i.ReadU16 ();
  
  return i.GetDistanceFrom (start);
}


HandleNotificationsClass::HandleNotificationsClass(void)
{

}

HandleNotificationsClass::~HandleNotificationsClass(void)
{

}


void
HandleNotificationsClass::SendNotificationToAPs(int notifType, 
                                                int numOfIfces, 
						Ipv4Address srcIPAddress, 
						Ipv4Address* ipAddressArray, 
						uint8_t manetConnection,
						Ptr<Packet> packet)
{
  APNotifL3Header apNotif;
  
  apNotif.SetMsgID (notifType);
  apNotif.SetNumOfIfces (numOfIfces);
  apNotif.SetSrcIPAddress (srcIPAddress);
  apNotif.SetIPAddresses (ipAddressArray, numOfIfces);
  apNotif.SetManetConnection (manetConnection);
  
  packet->AddHeader (apNotif);
}


int HandleNotificationsClass::ParseNotification (Ptr<Packet> packet, 
                                                 APNotifL3Header apHdr)
{  
  int status = 0;
  
  Ipv4Address* addresses = apHdr.GetIPAddresses ();
  if (apHdr.GetMsgID () == ASS_NOTIF)
    {
#ifdef DEBUG
      std::cout << "\n" << Simulator::Now () << " ---> Association notification for station " << addresses[0] << " is received from " << apHdr.GetSrcIPAddress () << "\n";
#endif
/*      
      status = AddOrModifyDestInfo(addresses, apHdr.GetSrcIPAddress (), apHdr.GetNumOfIfces (), apHdr.GetManetConnection ());
      if (status == DEST_INFO_ENTRY_ADDED)
        {
          NS_LOG_DEBUG ("ParseNotification, Entry Added in the destination info list");
        }
      else if (status == DEST_INFO_ENTRY_MODIFIED)
        {
          NS_LOG_DEBUG ("ParseNotification, Entry found and modified in the destination info list");
        }
      else
        {
          NS_LOG_DEBUG ("ParseNotification, Error in entering destination info");
        }
      RemoveDestBufferInfo (addresses[0]);
*/
      return ASS_NOTIF;
    }
  else if (apHdr.GetMsgID () == DISASS_NOTIF)
    {
#ifdef DEBUG
      std::cout << Simulator::Now () << " ---> Disassociation notification for station " << addresses[0] << " is received from " << apHdr.GetSrcIPAddress () << "\n";
#endif
      Ipv4Address alternateAddress[2];
      uint16_t len;
      status = RemoveDestInfo (addresses[0], alternateAddress, &len);
      if (status == DEST_INFO_ENTRY_REMOVED)
        {
          NS_LOG_DEBUG("ParseNotification, Entry removed from the destination info list");
        }
      else if (status == DEST_INFO_ENTRY_NOT_FOUND)
        {
          NS_LOG_DEBUG("ParseNotification, Entry not found in the destination info list");
        }
      else
        {
          NS_LOG_DEBUG("ParseNotification, Error in removing entry");
        }
	
      status = CheckAndAddDestBufferAP(addresses, apHdr.GetSrcIPAddress (), apHdr.GetNumOfIfces ());
      return DISASS_NOTIF;
    }
    
  else if (apHdr.GetMsgID () == FETCH_FRAMES_NOTIF)
    {
#ifdef DEBUG
      std::cout << Simulator::Now () << " ---> Fetch Frames notification for station " << addresses[0] << " is received from " << apHdr.GetSrcIPAddress () << "\n";
#endif
      return FETCH_FRAMES_NOTIF;
    }
    
  else if (apHdr.GetMsgID () == NEIGHBORHOOD_INFO_NOTIF)
    {
      std::cout << Simulator::Now () << " ---> Neighborhood information notification is received from " << apHdr.GetSrcIPAddress () << "\n";
//      RemoveDestBufferInfo (addresses[0]);
      
      return NEIGHBORHOOD_INFO_NOTIF;
    }
    
  else if (apHdr.GetMsgID () == INDIRECT_ASSOCIATION_NOTIF)
    {
      std::cout << Simulator::Now () << " ---> Indirect association notification for station " << addresses[0] << " is received from " << apHdr.GetSrcIPAddress () << "\n";
/*      
      status = AddOrModifyDestInfo(addresses, apHdr.GetSrcIPAddress (), apHdr.GetNumOfIfces (), apHdr.GetManetConnection ());
      RemoveDestBufferInfo (addresses[0]);
*/
      return INDIRECT_ASSOCIATION_NOTIF;
    }
    
  else if (apHdr.GetMsgID () == STA_ASS_NOTIF)
    {
      std::cout << Simulator::Now () << " ---> Station association notification for station " << addresses[0] << " is received from " << apHdr.GetSrcIPAddress () << "\n";
      return STA_ASS_NOTIF;
    }
    
  else if (apHdr.GetMsgID () == NEIGHBORHOOD_DISASS_NOTIF)
    {
      std::cout << Simulator::Now () << " ---> Neighborhood station disassociation notification for station " << addresses[0] << " is received from " << apHdr.GetSrcIPAddress () << "\n";
      return NEIGHBORHOOD_DISASS_NOTIF;
    }
    
  else if (apHdr.GetMsgID () == MANET_DISCONNECT_NOTIF)
    {
      std::cout << Simulator::Now () << " ---> Manet disconnection notification is received from " << apHdr.GetSrcIPAddress () << "\n";
      return MANET_DISCONNECT_NOTIF;
    }
  
  else
    {
//      std::cout << "Not a Notification\n";
      packet->AddHeader (apHdr);
      return 0;
    }
}



int HandleNotificationsClass::CheckForDestInfo (Ipv4Address destAddress, Ipv4Address* assAPAddress, Ipv4Address* infraStructureAddress)
{	
  DestInfo::iterator newIterator;		// link list iterator

  if (destInfoList.begin() == destInfoList.end ())
    {
      return DEST_INFO_LIST_DOESNT_EXIST;
    }
/*
  for (newIterator = destInfoList.begin(); newIterator != destInfoList.end(); newIterator++)
    {
      std::cout << "CheckForDestInfo: station " << (newIterator)->destNodeAddress << " is connected to " << newIterator->assAPAddress << "\n";
    }
*/  
  for (newIterator = destInfoList.begin(); newIterator != destInfoList.end(); newIterator++)
    {
//      std::cout << "CheckForDestInfo: entry is " << (newIterator)->destNodeAddress << "\n";
      if ((newIterator)->destNodeAddress == destAddress)
        {
          *assAPAddress = (newIterator)->assAPAddress;
//          std::cout << "CheckForDestInfo, Search Dest Info, Entry found\n";
          return DEST_INFO_ENTRY_FOUND;
        }
      else if ((newIterator)->destNodeAltAddress01 == destAddress ||
               (newIterator)->destNodeAltAddress02 == destAddress)
        {
	  *assAPAddress = (newIterator)->assAPAddress;
	  *infraStructureAddress = (newIterator)->destNodeAddress;
	  return DEST_INFO_ALTERNATE_FOUND;
	}
    }

  NS_LOG_DEBUG("CheckForDestInfo, Search Dest Info, Entry not found");
  return DEST_INFO_ENTRY_NOT_FOUND;
}


int HandleNotificationsClass::AddOrModifyDestInfo(Ipv4Address* addrArray, Ipv4Address assAPIPAddress, uint16_t len, uint8_t manetConnection)
{
  DestInfoSt tempDestInfo;
  
  DestInfo::iterator newIterator;		// link list iterator
  
  for (newIterator = destInfoList.begin(); newIterator != destInfoList.end(); newIterator++)
    {
      if ((newIterator)->destNodeAddress == addrArray[0])
        {
          (newIterator)->assAPAddress = assAPIPAddress;
	  if (len >= 2)
	    {
	      (newIterator)->destNodeAltAddress01 = addrArray[1];
	    }
	  if (len >= 3)
	    {
	      (newIterator)->destNodeAltAddress02 = addrArray[2];
	    }
	  (newIterator)->m_manetConnection = manetConnection;
          return DEST_INFO_ENTRY_MODIFIED;
        }
    }

  tempDestInfo.destNodeAddress = addrArray[0];
  tempDestInfo.assAPAddress = assAPIPAddress;
  if (len >= 2)
    {
      tempDestInfo.destNodeAltAddress01 = addrArray[1];
    }
  if (len >= 3)
    {
      tempDestInfo.destNodeAltAddress02 = addrArray[2];
    }
  tempDestInfo.m_manetConnection = manetConnection;
  destInfoList.push_back(tempDestInfo);
  
  return DEST_INFO_ENTRY_ADDED;
}


int HandleNotificationsClass::RemoveDestInfo(Ipv4Address srcIPAddress, Ipv4Address *alternateAddress, uint16_t* len)
{
  DestInfo::iterator newIterator;		// link list iterator
  
  int status = DEST_INFO_ENTRY_NOT_FOUND;
  for (newIterator = destInfoList.begin(); newIterator != destInfoList.end();)
    {
      if ((newIterator)->destNodeAddress == srcIPAddress ||
          (newIterator)->destNodeAltAddress01 == srcIPAddress ||
	  (newIterator)->destNodeAltAddress02 == srcIPAddress ||
          (newIterator)->assAPAddress == srcIPAddress)
        {
	  alternateAddress[0] = (newIterator)->destNodeAltAddress01;
	  alternateAddress[1] = (newIterator)->destNodeAltAddress02;
	  *len = 2;
          newIterator = destInfoList.erase (newIterator);
          NS_LOG_DEBUG("entry for station " << srcIPAddress << " is removed from the list");
//          std::cout << "entry for station " << srcIPAddress << " is removed from the list" << "\n";
          status = DEST_INFO_ENTRY_REMOVED;
          continue;
        }
      else
        {
	  newIterator++;
	}
    }
  
  return status;
}


int HandleNotificationsClass::RemoveDestBufferInfo (Ipv4Address srcIPAddress)
{
  DestBufferInfo::iterator newIterator;		// link list iterator
  
  int status = DEST_BUFFER_INFO_ENTRY_NOT_FOUND;
  for (newIterator = destBufferInfoList.begin(); newIterator != destBufferInfoList.end();)
    {
      if ((newIterator)->destNodeAddress == srcIPAddress ||
          (newIterator)->destNodeAltAddress01 == srcIPAddress ||
	  (newIterator)->destNodeAltAddress02 == srcIPAddress)
        {
          newIterator = destBufferInfoList.erase(newIterator);
	  NS_LOG_DEBUG("entry for station " << srcIPAddress << " is removed from the list");
          status = DEST_BUFFER_INFO_ENTRY_REMOVED;
	  continue;
        }
      else
        {
	  newIterator++;
	}
    }
  
  return status;
}


int HandleNotificationsClass::CheckAndAddDestBufferAP (Ipv4Address* addrArray, Ipv4Address assAPIpAddress, uint16_t len)
{
  DestBufferInfoSt tempDestBufferInfo;
  
  DestBufferInfo::iterator newIterator;		// link list iterator
  
  for (newIterator = destBufferInfoList.begin(); newIterator != destBufferInfoList.end(); newIterator++)
    {
      if ((newIterator)->destNodeAddress == addrArray[0])
        {
          newIterator->respAPAddress = assAPIpAddress;
	  if (len >= 2)
	    {
              newIterator->destNodeAltAddress01 = addrArray[1];
	    }
	  if (len >= 3)
	    {
              newIterator->destNodeAltAddress02 = addrArray[2];
	    }
          return DEST_BUFFER_INFO_ENTRY_MODIFIED;
        }
    }

  NS_LOG_DEBUG("HandleNotificationsClass::CheckAndAddDestBufferAP(), adding buffering AP to destination = " << addrArray[0]);
  tempDestBufferInfo.destNodeAddress = addrArray[0];
  tempDestBufferInfo.respAPAddress = assAPIpAddress;
  if (len >= 2)
    {
      tempDestBufferInfo.destNodeAltAddress01 = addrArray[1];
    }
  if (len >= 3)
    {
      tempDestBufferInfo.destNodeAltAddress02 = addrArray[2];
    }
  destBufferInfoList.push_back(tempDestBufferInfo);	
  
  return DEST_BUFFER_INFO_ENTRY_ADDED;
}


int HandleNotificationsClass::CheckForDestBufferInfo (Ipv4Address destAddress, Ipv4Address* respApAddress)
{	
  DestBufferInfo::iterator newIterator;		// link list iterator
  
  for (newIterator = destBufferInfoList.begin(); newIterator != destBufferInfoList.end(); newIterator++)
    {
      if ((newIterator)->destNodeAddress == destAddress ||
          (newIterator)->destNodeAltAddress01 == destAddress ||
	  (newIterator)->destNodeAltAddress02 == destAddress)
        {
          *respApAddress = (newIterator)->respAPAddress;
          NS_LOG_DEBUG("CheckForDestBufferInfo, Search Dest Info, Entry found");
          return DEST_BUFFER_INFO_ENTRY_FOUND;
        }
    }
  
  NS_LOG_DEBUG("CheckForDestBufferInfo, Search Dest Info, Entry not found");
  return DEST_BUFFER_INFO_ENTRY_NOT_FOUND;
}


int
HandleNotificationsClass::NeedToBufferPacket (Ipv4Address destAddress, std::list<Ptr<Ipv4Interface> > m_interfaces)
{
  typedef std::list<Ptr<Ipv4Interface> > Ipv4InterfaceList;
  Ipv4InterfaceList::const_iterator i;
  DestBufferInfo::iterator destBufferInfoIterator;
  for (destBufferInfoIterator = destBufferInfoList.begin(); destBufferInfoIterator != destBufferInfoList.end(); destBufferInfoIterator++)
    {
      if (destBufferInfoIterator->destNodeAddress == destAddress ||
          destBufferInfoIterator->destNodeAltAddress01 == destAddress ||
	  destBufferInfoIterator->destNodeAltAddress02 == destAddress)
        {          
	  for (i = m_interfaces.begin (); i != m_interfaces.end (); i++)
	    {
	      for (uint32_t j = 0; j < (*i)->GetNAddresses (); j++)
                {
                  if ((*i)->GetAddress (j).GetLocal () == destBufferInfoIterator->respAPAddress)
	            {
//		      std::cout << "Local AP Address is " << (*i)->GetAddress (j).GetLocal () << "\n";
		      return BUFFER_LOCAL_AP_RESPONSIBLE_FOR_BUFFER;
		    }		  
                } 
	    }
	  return BUFFER_REMOTE_AP_RESPONSIBLE_FOR_BUFFER;
	}
    }
  return BUFFER_DEST_ENTRY_DOESNT_EXIST;
}

} // ns3 namespace
